---@type SeasonOfDiscovery
local SeasonOfDiscovery = QuestieLoader:ImportModule("SeasonOfDiscovery")
---@type QuestieDB
local QuestieDB = QuestieLoader:ImportModule("QuestieDB")
---@type ZoneDB
local ZoneDB = QuestieLoader:ImportModule("ZoneDB")

--- Load the base quests for Season of Discovery
--- These are generated, do NOT EDIT the data entries here.
--- If you want to edit a quest, do so in sodQuestFixes.lua
function SeasonOfDiscovery:LoadBaseQuests()
    local questKeys = QuestieDB.questKeys
    local zoneIDs = ZoneDB.zoneIDs
    local raceIDs = QuestieDB.raceKeys
    local classIDs = QuestieDB.classKeys
    local sortKeys = QuestieDB.sortKeys

    return {
        [76156] = {
            [questKeys.name] = "Stalk With The Earthmother",
            [questKeys.startedBy] = {{205729}},
            [questKeys.finishedBy] = {{205729,}},
            [questKeys.requiredLevel] = 4,
            [questKeys.questLevel] = 6,
            [questKeys.requiredRaces] = raceIDs.ALL_HORDE,
            [questKeys.requiredClasses] = classIDs.SHAMAN,
            [questKeys.objectivesText] = {"Sneak into the Venture Company mine southeast of Thunder Bluff and collect 5 Seaforium Mining Charges from carts of blasting supplies, then return them to Boarton Shadetotem in Thunder Bluff."},
            [questKeys.objectives] = {nil,nil,{{206157}}},
        },
        [76160] = {
            [questKeys.name] = "Stalk With The Earthmother",
            [questKeys.startedBy] = {{205729}},
            [questKeys.finishedBy] = {{205729,}},
            [questKeys.requiredLevel] = 4,
            [questKeys.questLevel] = 6,
            [questKeys.requiredRaces] = raceIDs.ALL_HORDE,
            [questKeys.requiredClasses] = classIDs.SHAMAN,
            [questKeys.objectivesText] = {"Gather 8 Windfury Cones north of Thunder Bluff, use them with the Mortar and Pestle, then return to Boarton Shadetotem in Thunder Bluff with the result."},
            [questKeys.objectives] = {nil,nil,{{206175},{206176}}},
        },
        [76240] = {
            [questKeys.name] = "Stalk With The Earthmother",
            [questKeys.startedBy] = {{205729}},
            [questKeys.finishedBy] = {{205729,}},
            [questKeys.requiredLevel] = 4,
            [questKeys.questLevel] = 6,
            [questKeys.requiredRaces] = raceIDs.ALL_HORDE,
            [questKeys.requiredClasses] = classIDs.SHAMAN,
            [questKeys.objectivesText] = {"Buy or catch a Raw Brilliant Smallfish, then use the Knife Set to fillet it in front of Boarton Shadetotem in Thunder Bluff."},
            [questKeys.objectives] = {nil,nil,{{206345},{206344}}},
        },
        [77568] = {
            [questKeys.name] = "A Hunter's Strength",
            [questKeys.startedBy] = {{3596}},
            [questKeys.finishedBy] = {{3596,}},
            [questKeys.requiredLevel] = 2,
            [questKeys.questLevel] = 2,
            [questKeys.requiredRaces] = raceIDs.ALL_ALLIANCE,
            [questKeys.requiredClasses] = classIDs.HUNTER,
            [questKeys.objectivesText] = {"Defeat Githyiss the Vile in Shadowthread Cave and recover the lost rune. Learn the rune, then report back to Ayanna Everstride in Shadowglen."},
            [questKeys.objectives] = {nil,nil,nil,nil,nil,{{410121}}},
        },
        [77571] = {
            [questKeys.name] = "Relics of the Kaldorei",
            [questKeys.startedBy] = {{3597}},
            [questKeys.finishedBy] = {{3597,}},
            [questKeys.requiredLevel] = 2,
            [questKeys.questLevel] = 2,
            [questKeys.requiredRaces] = raceIDs.ALL_ALLIANCE,
            [questKeys.requiredClasses] = classIDs.DRUID,
            [questKeys.objectivesText] = {"Recover the relic from the grellkin in Shadowglen. Follow the relic's guidance to learn a new ability, then report back to Mardant Strongoak."},
            [questKeys.objectives] = {nil,nil,nil,nil,nil,{{410061}}},
        },
        [77573] = {
            [questKeys.name] = "Second-Story Work",
            [questKeys.startedBy] = {{3594}},
            [questKeys.finishedBy] = {{3594,}},
            [questKeys.requiredLevel] = 2,
            [questKeys.questLevel] = 2,
            [questKeys.requiredRaces] = raceIDs.ALL_ALLIANCE,
            [questKeys.requiredClasses] = classIDs.ROGUE,
            [questKeys.objectivesText] = {"Retrieve the rune from the hidden idol, then use it to learn a new ability. Afterwards, return to Frahun Shadewhisper."},
            [questKeys.objectives] = {nil,nil,nil,nil,nil,{{400105}}},
        },
        [77574] = {
            [questKeys.name] = "Meditation on Elune",
            [questKeys.startedBy] = {{3595}},
            [questKeys.finishedBy] = {{3595,}},
            [questKeys.requiredLevel] = 2,
            [questKeys.questLevel] = 2,
            [questKeys.requiredRaces] = raceIDs.ALL_ALLIANCE,
            [questKeys.requiredClasses] = classIDs.PRIEST,
            [questKeys.objectivesText] = {"Kneel at the moonwell to meditate on Elune, then use the memory to learn a new ability. Afterwards, return to Shanda in Shadowglen."},
            [questKeys.objectives] = {nil,nil,{{205951}}},
        },
        [77575] = {
            [questKeys.name] = "Amidst the Shadowed Webs",
            [questKeys.startedBy] = {{3593}},
            [questKeys.finishedBy] = {{3593,}},
            [questKeys.requiredLevel] = 2,
            [questKeys.questLevel] = 2,
            [questKeys.requiredRaces] = raceIDs.ALL_ALLIANCE,
            [questKeys.requiredClasses] = classIDs.WARRIOR,
            [questKeys.objectivesText] = {"Slay webwood spiders in Shadowthread Cave and recover the lost rune. Learn the rune, then report back to Alyissia in Shadowglen."},
            [questKeys.objectives] = {nil,nil,nil,nil,nil,{{403470}}},
        },
        [77582] = {
            [questKeys.name] = "A Trial of Fitness",
            [questKeys.startedBy] = {{3153}},
            [questKeys.finishedBy] = {{3153,}},
            [questKeys.requiredLevel] = 2,
            [questKeys.questLevel] = 2,
            [questKeys.requiredRaces] = raceIDs.ALL_HORDE,
            [questKeys.requiredClasses] = classIDs.WARRIOR,
            [questKeys.objectivesText] = {"Find the Hidden Cache in the cliffs behind Frang. Learn the rune inside, then report back to Frang in the Valley of Trials."},
            [questKeys.objectives] = {nil,nil,nil,nil,nil,{{403470}}},
        },
        [77583] = {
            [questKeys.name] = "Atop the Cliffs",
            [questKeys.startedBy] = {{3155}},
            [questKeys.finishedBy] = {{3155,}},
            [questKeys.requiredLevel] = 2,
            [questKeys.questLevel] = 2,
            [questKeys.requiredRaces] = raceIDs.ALL_HORDE,
            [questKeys.requiredClasses] = classIDs.ROGUE,
            [questKeys.objectivesText] = {"Find the Hidden Cache in the cliffs surrounding the Valley of Trials. Learn the rune inside, then report back to Rwag in The Den."},
            [questKeys.objectives] = {nil,nil,nil,nil,nil,{{400105}}},
        },
        [77584] = {
            [questKeys.name] = "Hunt for the Rune",
            [questKeys.startedBy] = {{3154}},
            [questKeys.finishedBy] = {{3154,}},
            [questKeys.requiredLevel] = 2,
            [questKeys.questLevel] = 2,
            [questKeys.requiredRaces] = raceIDs.ALL_HORDE,
            [questKeys.requiredClasses] = classIDs.HUNTER,
            [questKeys.objectivesText] = {"Find the lost rune by slaying scorpids in the Valley of Trials. Learn the rune's power, then report back to Jen'sahn."},
            [questKeys.objectives] = {nil,nil,nil,nil,nil,{{410121}}},
        },
        [77585] = {
            [questKeys.name] = "Icons of Power",
            [questKeys.startedBy] = {{3157}},
            [questKeys.finishedBy] = {{3157,}},
            [questKeys.requiredLevel] = 2,
            [questKeys.questLevel] = 2,
            [questKeys.requiredRaces] = raceIDs.ALL_HORDE,
            [questKeys.requiredClasses] = classIDs.SHAMAN,
            [questKeys.objectivesText] = {"Find the stolen icon by slaying scorpids in the Valley of Trials. Learn its power, then report back to Shikrik."},
            [questKeys.objectives] = {nil,nil,nil,nil,nil,{{410094}}},
        },
        [77586] = {
            [questKeys.name] = "Stolen Power",
            [questKeys.startedBy] = {{3156}},
            [questKeys.finishedBy] = {{3156,}},
            [questKeys.requiredLevel] = 2,
            [questKeys.questLevel] = 2,
            [questKeys.requiredRaces] = raceIDs.ALL_HORDE,
            [questKeys.requiredClasses] = classIDs.WARLOCK,
            [questKeys.objectivesText] = {"Find the stolen rune inside of the Burning Blade Coven. Learn its power, then report back to Nartok in The Den."},
            [questKeys.objectives] = {nil,nil,nil,nil,nil,{{403919}}},
        },
        [77587] = {
            [questKeys.name] = "Icons of Power",
            [questKeys.startedBy] = {{3157}},
            [questKeys.finishedBy] = {{3157,}},
            [questKeys.requiredLevel] = 2,
            [questKeys.questLevel] = 2,
            [questKeys.requiredRaces] = raceIDs.ALL_HORDE,
            [questKeys.requiredClasses] = classIDs.SHAMAN,
            [questKeys.objectivesText] = {"Find the stolen icon by slaying scorpids in the Valley of Trials. Learn its power, then report back to Shikrik."},
            [questKeys.objectives] = {nil,nil,nil,nil,nil,{{410094}}},
        },
        [77588] = {
            [questKeys.name] = "A Trial of Fitness",
            [questKeys.startedBy] = {{3153}},
            [questKeys.finishedBy] = {{3153,}},
            [questKeys.requiredLevel] = 2,
            [questKeys.questLevel] = 2,
            [questKeys.requiredRaces] = raceIDs.ALL_HORDE,
            [questKeys.requiredClasses] = classIDs.WARRIOR,
            [questKeys.objectivesText] = {"Find the Hidden Cache in the cliffs behind Frang. Learn the rune inside, then report back to Frang in the Valley of Trials."},
            [questKeys.objectives] = {nil,nil,nil,nil,nil,{{403470}}},
        },
        [77590] = {
            [questKeys.name] = "Rugged Terrain",
            [questKeys.startedBy] = {{3154}},
            [questKeys.finishedBy] = {{3154,}},
            [questKeys.requiredLevel] = 2,
            [questKeys.questLevel] = 2,
            [questKeys.requiredRaces] = raceIDs.ALL_HORDE,
            [questKeys.requiredClasses] = classIDs.HUNTER,
            [questKeys.objectivesText] = {"Find the lost rune by slaying scorpids in the Valley of Trials. Learn the rune's power, then report back to Jen'sahn."},
            [questKeys.objectives] = {nil,nil,nil,nil,nil,{{410121}}},
        },
        [77592] = {
            [questKeys.name] = "Atop the Cliffs",
            [questKeys.startedBy] = {{3155}},
            [questKeys.finishedBy] = {{3155,}},
            [questKeys.requiredLevel] = 2,
            [questKeys.questLevel] = 2,
            [questKeys.requiredRaces] = raceIDs.ALL_HORDE,
            [questKeys.requiredClasses] = classIDs.ROGUE,
            [questKeys.objectivesText] = {"Find the Hidden Cache in the cliffs surrounding the Valley of Trials. Learn the rune inside, then report back to Rwag in The Den."},
            [questKeys.objectives] = {nil,nil,nil,nil,nil,{{400105}}},
        },
        [77616] = {
            [questKeys.name] = "The Lost Rune",
            [questKeys.startedBy] = {{911}},
            [questKeys.finishedBy] = {{911,}},
            [questKeys.requiredLevel] = 2,
            [questKeys.questLevel] = 2,
            [questKeys.requiredRaces] = raceIDs.ALL_ALLIANCE,
            [questKeys.requiredClasses] = classIDs.WARRIOR,
            [questKeys.objectivesText] = {"Find the lost rune within Echo Ridge Mine and use it to learn a new ability, then report back to Llane Beshere in Northshire."},
            [questKeys.objectives] = {nil,nil,nil,nil,nil,{{403470}}},
        },
        [77617] = {
            [questKeys.name] = "Relics of the Light",
            [questKeys.startedBy] = {{925}},
            [questKeys.finishedBy] = {{925,}},
            [questKeys.requiredLevel] = 2,
            [questKeys.questLevel] = 2,
            [questKeys.requiredRaces] = raceIDs.ALL_ALLIANCE,
            [questKeys.requiredClasses] = classIDs.PALADIN,
            [questKeys.objectivesText] = {"Recover the libram and follow its guidance to learn a new ability, then return to Brother Sammuel in Northshire."},
            [questKeys.objectives] = {nil,nil,nil,nil,nil,{{410002}}},
        },
        [77618] = {
            [questKeys.name] = "Thrice Stolen",
            [questKeys.startedBy] = {{915}},
            [questKeys.finishedBy] = {{915,}},
            [questKeys.requiredLevel] = 2,
            [questKeys.questLevel] = 2,
            [questKeys.requiredRaces] = raceIDs.ALL_ALLIANCE,
            [questKeys.requiredClasses] = classIDs.ROGUE,
            [questKeys.objectivesText] = {"Recover the lost rune from the Defias camps and use it to learn a new ability, then return to Jorik Kerridan in Northshire."},
            [questKeys.objectives] = {nil,nil,nil,nil,nil,{{400105}}},
        },
        [77619] = {
            [questKeys.name] = "Meditation on the Light",
            [questKeys.startedBy] = {{375}},
            [questKeys.finishedBy] = {{375,}},
            [questKeys.requiredLevel] = 2,
            [questKeys.questLevel] = 2,
            [questKeys.requiredRaces] = raceIDs.ALL_ALLIANCE,
            [questKeys.requiredClasses] = classIDs.PRIEST,
            [questKeys.objectivesText] = {"Slay kobolds in Echo Ridge Mine to receive a memory. Kneel within Northshire Abbey to meditate on the light, then use the memory to learn a new ability. Afterwards, return to Priestess Anetta."},
            [questKeys.objectives] = {nil,nil,nil,nil,nil,{{402862}}},
        },
        [77620] = {
            [questKeys.name] = "Spell Research",
            [questKeys.startedBy] = {{198}},
            [questKeys.finishedBy] = {{198,}},
            [questKeys.requiredLevel] = 2,
            [questKeys.questLevel] = 2,
            [questKeys.requiredRaces] = raceIDs.ALL_ALLIANCE,
            [questKeys.requiredClasses] = classIDs.MAGE,
            [questKeys.objectivesText] = {"Recover research notes from the Defias bandits and use them to learn a new spell, then return to Khelden Bremen in Northshire."},
            [questKeys.objectives] = {nil,nil,nil,nil,nil,{{401760}}},
        },
        [77621] = {
            [questKeys.name] = "Stolen Power",
            [questKeys.startedBy] = {{459}},
            [questKeys.finishedBy] = {{459,}},
            [questKeys.requiredLevel] = 2,
            [questKeys.questLevel] = 2,
            [questKeys.requiredRaces] = raceIDs.ALL_ALLIANCE,
            [questKeys.requiredClasses] = classIDs.WARLOCK,
            [questKeys.objectivesText] = {"Recover the rune from the Defias camps to the east and use it to learn a new ability, then return to Drusilla La Salle in Northshire."},
            [questKeys.objectives] = nil,
        },
        [77642] = {
            [questKeys.name] = "Wisdom of the Loa",
            [questKeys.startedBy] = {{3707}},
            [questKeys.finishedBy] = {{3707,}},
            [questKeys.requiredLevel] = 2,
            [questKeys.questLevel] = 2,
            [questKeys.requiredRaces] = raceIDs.ALL_HORDE,
            [questKeys.requiredClasses] = classIDs.PRIEST,
            [questKeys.objectivesText] = {"Kneel at the Loa Altar in Sen'jin Village. Commune with the Loa spirit, then use the memory to learn a new ability. Afterwards, return to Ken'jai  in the Valley of Trails."},
            [questKeys.objectives] = {nil,nil,{{205951}}},
        },
        [77643] = {
            [questKeys.name] = "Spell Research",
            [questKeys.startedBy] = {{5884}},
            [questKeys.finishedBy] = {{5884,}},
            [questKeys.requiredLevel] = 2,
            [questKeys.questLevel] = 2,
            [questKeys.requiredRaces] = raceIDs.ALL_HORDE,
            [questKeys.requiredClasses] = classIDs.MAGE,
            [questKeys.objectivesText] = {"Find the stolen spell notes inside the Burning Blade Coven, then use them to learn a new ability. Afterwards, return to Mai'ah in the Valley of Trails."},
            [questKeys.objectives] = {nil,nil,nil,nil,nil,{{401760}}},
        },
        [77648] = {
            [questKeys.name] = "Relics of the Tauren",
            [questKeys.startedBy] = {{3060}},
            [questKeys.finishedBy] = {{3060,}},
            [questKeys.requiredLevel] = 2,
            [questKeys.questLevel] = 2,
            [questKeys.requiredRaces] = raceIDs.ALL_HORDE,
            [questKeys.requiredClasses] = classIDs.DRUID,
            [questKeys.objectivesText] = {"Recover the stolen relic from Brambleblade Ravine. Follow the relic's guidance to learn a new ability, then report back to Gart Mistrunner in Camp Narache."},
            [questKeys.objectives] = {nil,nil,nil,nil,nil,{{410061}}},
        },
        [77649] = {
            [questKeys.name] = "A Hunter's Strength",
            [questKeys.startedBy] = {{3061}},
            [questKeys.finishedBy] = {{3061,}},
            [questKeys.requiredLevel] = 2,
            [questKeys.questLevel] = 2,
            [questKeys.requiredRaces] = raceIDs.ALL_HORDE,
            [questKeys.requiredClasses] = classIDs.HUNTER,
            [questKeys.objectivesText] = {"Find the missing rune by slaying Bristleback Battleboars in Brambleblade Ravine. Use the rune to learn a new ability, then report back to Lanka Farshot in Camp Narache."},
            [questKeys.objectives] = {nil,nil,nil,nil,nil,{{410121}}},
        },
        [77651] = {
            [questKeys.name] = "Into the Brambles",
            [questKeys.startedBy] = {{3059}},
            [questKeys.finishedBy] = {{3059,}},
            [questKeys.requiredLevel] = 2,
            [questKeys.questLevel] = 2,
            [questKeys.requiredRaces] = raceIDs.ALL_HORDE,
            [questKeys.requiredClasses] = classIDs.WARRIOR,
            [questKeys.objectivesText] = {"Recover the lost rune from Brambleblade Ravine. Use the rune to learn a new ability, then report back to Harutt Thunderhorn in Camp Narache."},
            [questKeys.objectives] = {nil,nil,nil,nil,nil,{{403470}}},
        },
        [77652] = {
            [questKeys.name] = "Icons of Power",
            [questKeys.startedBy] = {{3062}},
            [questKeys.finishedBy] = {{3062,}},
            [questKeys.requiredLevel] = 2,
            [questKeys.questLevel] = 2,
            [questKeys.requiredRaces] = raceIDs.ALL_HORDE,
            [questKeys.requiredClasses] = classIDs.SHAMAN,
            [questKeys.objectivesText] = {"Recover the lost icon from the Bristleback Shamans in Brambleblade Ravine. Learn its power, then report back to Harutt Thunderhorn in Camp Narache."},
            [questKeys.objectives] = {nil,nil,nil,nil,nil,{{410094}}},
        },
        [77655] = {
            [questKeys.name] = "The Lost Rune",
            [questKeys.startedBy] = {{912}},
            [questKeys.finishedBy] = {{912,}},
            [questKeys.requiredLevel] = 2,
            [questKeys.questLevel] = 2,
            [questKeys.requiredRaces] = raceIDs.ALL_ALLIANCE,
            [questKeys.requiredClasses] = classIDs.WARRIOR,
            [questKeys.objectivesText] = {"Find the lost rune carried by a  Frostmane troll in Coldridge Valley. Use it to learn a new ability, then report back to Thran Khorman in Anvilmar."},
            [questKeys.objectives] = {nil,nil,nil,nil,nil,{{403470}}},
        },
        [77656] = {
            [questKeys.name] = "The Lost Rune",
            [questKeys.startedBy] = {{912}},
            [questKeys.finishedBy] = {{912,}},
            [questKeys.requiredLevel] = 2,
            [questKeys.questLevel] = 2,
            [questKeys.requiredRaces] = raceIDs.ALL_ALLIANCE,
            [questKeys.requiredClasses] = classIDs.WARRIOR,
            [questKeys.objectivesText] = {"Find the lost rune carried by a Frostmane troll in Coldridge Valley. Use it to learn a new ability, then report back to Thran Khorman in Anvilmar."},
            [questKeys.objectives] = {nil,nil,nil,nil,nil,{{403470}}},
        },
        [77657] = {
            [questKeys.name] = "Relics of the Light",
            [questKeys.startedBy] = {{926}},
            [questKeys.finishedBy] = {{926,}},
            [questKeys.requiredLevel] = 2,
            [questKeys.questLevel] = 2,
            [questKeys.requiredRaces] = raceIDs.ALL_ALLIANCE,
            [questKeys.requiredClasses] = classIDs.PALADIN,
            [questKeys.objectivesText] = {"Recover the stolen libram carried by a Frostmane troll in Coldridge Valley. Follow its guidance to learn a new ability, then return to Bromos Grummner in Anvilmar."},
            [questKeys.objectives] = {nil,nil,nil,nil,nil,{{410002}}},
        },
        [77658] = {
            [questKeys.name] = "Thrice Stolen",
            [questKeys.startedBy] = {{916}},
            [questKeys.finishedBy] = {{916,}},
            [questKeys.requiredLevel] = 2,
            [questKeys.questLevel] = 2,
            [questKeys.requiredRaces] = raceIDs.ALL_ALLIANCE,
            [questKeys.requiredClasses] = classIDs.ROGUE,
            [questKeys.objectivesText] = {"Recover the stolen rune from the cave of Frostmane trolls in Coldridge Valley. Use it to learn a new ability, then return to Solm Hargrin in Anvilmar."},
            [questKeys.objectives] = {nil,nil,nil,nil,nil,{{400105}}},
        },
        [77659] = {
            [questKeys.name] = "Thrice Stolen",
            [questKeys.startedBy] = {{916}},
            [questKeys.finishedBy] = {{916,}},
            [questKeys.requiredLevel] = 2,
            [questKeys.questLevel] = 2,
            [questKeys.requiredRaces] = raceIDs.ALL_ALLIANCE,
            [questKeys.requiredClasses] = classIDs.ROGUE,
            [questKeys.objectivesText] = {"Recover the stolen rune from the cave of Frostmane trolls in Coldridge Valley. Use it to learn a new ability, then return to Solm Hargrin in Anvilmar."},
            [questKeys.objectives] = {nil,nil,nil,nil,nil,{{400105}}},
        },
        [77660] = {
            [questKeys.name] = "Trek Through the Caves",
            [questKeys.startedBy] = {{895}},
            [questKeys.finishedBy] = {{895,}},
            [questKeys.requiredLevel] = 2,
            [questKeys.questLevel] = 2,
            [questKeys.requiredRaces] = raceIDs.ALL_ALLIANCE,
            [questKeys.requiredClasses] = classIDs.HUNTER,
            [questKeys.objectivesText] = {"Recover the stolen rune from the cave of Frostmane trolls in Coldridge Valley. Use the rune to learn a new ability, then report back to Thorgas Grimson in Anvilmar."},
            [questKeys.objectives] = {nil,nil,nil,nil,nil,{{410121}}},
        },
        [77661] = {
            [questKeys.name] = "Meditation on the Light",
            [questKeys.startedBy] = {{837}},
            [questKeys.finishedBy] = {{837,}},
            [questKeys.requiredLevel] = 2,
            [questKeys.questLevel] = 2,
            [questKeys.requiredRaces] = raceIDs.ALL_ALLIANCE,
            [questKeys.requiredClasses] = classIDs.PRIEST,
            [questKeys.objectivesText] = {"Find a memory of the past inside of a chest at the trogg camp near Anvilmar. Then, kneel at the Altar of the Light within Anvilmar to meditate on the light, and use the memory to learn a new ability. Afterwards, speak to Branstock Khalder."},
            [questKeys.objectives] = {nil,nil,nil,nil,nil,{{402862}}},
        },
        [77666] = {
            [questKeys.name] = "Stolen Power",
            [questKeys.startedBy] = {{460}},
            [questKeys.finishedBy] = {{460,}},
            [questKeys.requiredLevel] = 2,
            [questKeys.questLevel] = 2,
            [questKeys.requiredRaces] = raceIDs.ALL_ALLIANCE,
            [questKeys.requiredClasses] = classIDs.WARLOCK,
            [questKeys.objectivesText] = {"Recover the rune from the group of Troggs, southwest of Anvilmar, and use it to learn a new ability. Then, return to Alamar Grimm in Anvilmar."},
            [questKeys.objectives] = nil,
        },
        [77667] = {
            [questKeys.name] = "Spell Research",
            [questKeys.startedBy] = {{944}},
            [questKeys.finishedBy] = {{944,}},
            [questKeys.requiredLevel] = 2,
            [questKeys.questLevel] = 2,
            [questKeys.requiredRaces] = raceIDs.ALL_ALLIANCE,
            [questKeys.requiredClasses] = classIDs.MAGE,
            [questKeys.objectivesText] = {"Find the stolen spell notes at the trogg camp to the southwest of Anvilmar, then use them to learn a new ability. Afterwards, return to Marryk Nurribit in Anvilmar."},
            [questKeys.objectives] = {nil,nil,nil,nil,nil,{{401760}}},
        },
        [77668] = {
            [questKeys.name] = "The Lost Rune",
            [questKeys.startedBy] = {{2119}},
            [questKeys.finishedBy] = {{2119,}},
            [questKeys.requiredLevel] = 2,
            [questKeys.questLevel] = 2,
            [questKeys.requiredRaces] = raceIDs.ALL_HORDE,
            [questKeys.requiredClasses] = classIDs.WARRIOR,
            [questKeys.objectivesText] = {"Find the rune hidden in Night Web's Hollow and use it to learn a new technique, then report back to Dannal Stern in Deathknell."},
            [questKeys.objectives] = {nil,nil,nil,nil,nil,{{403470}}},
        },
        [77669] = {
            [questKeys.name] = "The Scarlet Rune",
            [questKeys.startedBy] = {{2122}},
            [questKeys.finishedBy] = {{2122,}},
            [questKeys.requiredLevel] = 2,
            [questKeys.questLevel] = 2,
            [questKeys.requiredRaces] = raceIDs.ALL_HORDE,
            [questKeys.requiredClasses] = classIDs.ROGUE,
            [questKeys.objectivesText] = {"Pickpocket or kill Scarlet Converts to find a rune, then use it to learn a new ability. Afterwards, return to David Trias in Deathknell."},
            [questKeys.objectives] = {nil,nil,nil,nil,nil,{{400105}}},
        },
        [77670] = {
            [questKeys.name] = "Meditation on Undeath",
            [questKeys.startedBy] = {{2123}},
            [questKeys.finishedBy] = {{2123,}},
            [questKeys.requiredLevel] = 2,
            [questKeys.questLevel] = 2,
            [questKeys.requiredRaces] = raceIDs.ALL_HORDE,
            [questKeys.requiredClasses] = classIDs.PRIEST,
            [questKeys.objectivesText] = {"Kneel in the graveyard to meditate on undeath, then use the rune to learn a new ability. Afterwards, return to Dark Cleric Duesten in the Deathknell chapel."},
            [questKeys.objectives] = {nil,nil,{{205951}}},
        },
        [77671] = {
            [questKeys.name] = "Spell Research",
            [questKeys.startedBy] = {{2124}},
            [questKeys.finishedBy] = {{2124,}},
            [questKeys.requiredLevel] = 2,
            [questKeys.questLevel] = 2,
            [questKeys.requiredRaces] = raceIDs.ALL_HORDE,
            [questKeys.requiredClasses] = classIDs.MAGE,
            [questKeys.objectivesText] = {"Kill Scarlet Initiates to find spell notes and use them to learn a new ability, then return to Isabella in Deathknell."},
            [questKeys.objectives] = {nil,nil,nil,nil,nil,{{401760}}},
        },
        [77672] = {
            [questKeys.name] = "The Lost Rune",
            [questKeys.startedBy] = {{2126}},
            [questKeys.finishedBy] = {{2126,}},
            [questKeys.requiredLevel] = 2,
            [questKeys.questLevel] = 2,
            [questKeys.requiredRaces] = raceIDs.ALL_HORDE,
            [questKeys.requiredClasses] = classIDs.WARLOCK,
            [questKeys.objectivesText] = {"Recover the rune from Night Web's Hollow and use it to learn a new ability, then return to Maximillion in Deathknell."},
            [questKeys.objectives] = {nil,nil,nil,nil,nil,{{403919}}},
        },
        [78088] = {
            [questKeys.name] = "A Strange Artifact",
            [questKeys.startedBy] = {{3663}},
            [questKeys.finishedBy] = {{3663,}},
            [questKeys.requiredLevel] = 1,
            [questKeys.questLevel] = 25,
            [questKeys.requiredRaces] = raceIDs.ALL_ALLIANCE,
            [questKeys.requiredClasses] = classIDs.PALADIN,
            [questKeys.objectivesText] = {"Did you find something in the tower?"},
            [questKeys.objectives] = {nil,nil,{{209836}}},
        },
        [78089] = {
            [questKeys.name] = "Advice From Stormwind",
            [questKeys.startedBy] = {{3663}},
            [questKeys.finishedBy] = {{5492,}},
            [questKeys.requiredLevel] = 1,
            [questKeys.questLevel] = 25,
            [questKeys.requiredRaces] = raceIDs.ALL_ALLIANCE,
            [questKeys.requiredClasses] = classIDs.PALADIN,
            [questKeys.objectivesText] = {"Consult the paladins of Stormwind for advice on the orb."},
            [questKeys.objectives] = nil,
        },
        [78090] = {
            [questKeys.name] = "A Second Opinion",
            [questKeys.startedBy] = {{5492}},
            [questKeys.finishedBy] = {{5495,}},
            [questKeys.requiredLevel] = 1,
            [questKeys.questLevel] = 25,
            [questKeys.requiredRaces] = raceIDs.ALL_ALLIANCE,
            [questKeys.requiredClasses] = classIDs.PALADIN,
            [questKeys.objectivesText] = {"Find the warlock sanctum within Stormwind and seek advice on the orb."},
            [questKeys.objectives] = nil,
        },
        [78091] = {
            [questKeys.name] = "Earning Your Salt",
            [questKeys.startedBy] = {{5495}},
            [questKeys.finishedBy] = {{5495,}},
            [questKeys.requiredLevel] = 1,
            [questKeys.questLevel] = 25,
            [questKeys.requiredRaces] = raceIDs.ALL_ALLIANCE,
            [questKeys.requiredClasses] = classIDs.PALADIN,
            [questKeys.objectivesText] = {"Collect 14 Summoner's Salt from Blackrock Summoners in Redridge Mountains, then return to Ursula Deline in Stormwind."},
            [questKeys.objectives] = {nil,nil,{{209778}}},
        },
        [78092] = {
            [questKeys.name] = "It Must Be Destroyed",
            [questKeys.startedBy] = {{5495}},
            [questKeys.finishedBy] = nil,
            [questKeys.requiredLevel] = 1,
            [questKeys.questLevel] = 25,
            [questKeys.requiredRaces] = raceIDs.ALL_ALLIANCE,
            [questKeys.requiredClasses] = classIDs.PALADIN,
            [questKeys.objectivesText] = {"Find a way to destroy the orb."},
            [questKeys.objectives] = {nil,nil,{{209779}}},
        },
        [78093] = {
            [questKeys.name] = "Return to Delgren",
            [questKeys.startedBy] = {{3663}},
            [questKeys.finishedBy] = {{3663,}},
            [questKeys.requiredLevel] = 1,
            [questKeys.questLevel] = 25,
            [questKeys.requiredRaces] = raceIDs.ALL_ALLIANCE,
            [questKeys.requiredClasses] = classIDs.PALADIN,
            [questKeys.objectivesText] = {"Return the Orb Shards to Delgren."},
            [questKeys.objectives] = nil,
        },
        [78114] = {
            [questKeys.name] = "Wild Wyvern Wrangling",
            [questKeys.startedBy] = {{210845}},
            [questKeys.finishedBy] = {{210845,}},
            [questKeys.requiredLevel] = 1,
            [questKeys.questLevel] = 25,
            [questKeys.requiredRaces] = raceIDs.NONE,
            [questKeys.requiredClasses] = classIDs.HUNTER,
            [questKeys.objectivesText] = {"Bring a Hypnotic Crystal and a Gnarled Wand of Wild Magic to Jixo Madrocket in the Stonetalon Mountains."},
            [questKeys.objectives] = {nil,nil,{{209838},{209840}}},
        },
        [78121] = {
            [questKeys.name] = "Wrangling a Wild Wyvern",
            [questKeys.startedBy] = {{210845}},
            [questKeys.finishedBy] = {{210845,}},
            [questKeys.requiredLevel] = 1,
            [questKeys.questLevel] = 25,
            [questKeys.requiredRaces] = raceIDs.NONE,
            [questKeys.requiredClasses] = classIDs.HUNTER,
            [questKeys.objectivesText] = {"Follow Jixo Madrocket, and watch him tame a Wyvern."},
            [questKeys.objectives] = nil,
        },
        [78124] = {
            [questKeys.name] = "Nar'thalas Almanac",
            [questKeys.startedBy] = {{211033}},
            [questKeys.finishedBy] = {{211022,211033,}},
            [questKeys.requiredLevel] = 1,
            [questKeys.questLevel] = 20,
            [questKeys.requiredRaces] = raceIDs.NONE,
            [questKeys.requiredClasses] = classIDs.MAGE,
            [questKeys.objectivesText] = {"Have you brought something to add to our collection?"},
            [questKeys.objectives] = {nil,nil,{{209843}}},
        },
        [78127] = {
            [questKeys.name] = "The Dalaran Digest",
            [questKeys.startedBy] = {{211033}},
            [questKeys.finishedBy] = {{211022,211033,}},
            [questKeys.requiredLevel] = 1,
            [questKeys.questLevel] = 20,
            [questKeys.requiredRaces] = raceIDs.NONE,
            [questKeys.requiredClasses] = classIDs.MAGE,
            [questKeys.objectivesText] = {"Have you brought something to add to our collection?"},
            [questKeys.objectives] = {nil,nil,{{209844}}},
        },
        [78132] = {
            [questKeys.name] = "Dragonslayer's Helm",
            [questKeys.startedBy] = {{210995}},
            [questKeys.finishedBy] = {{210995,}},
            [questKeys.requiredLevel] = 1,
            [questKeys.questLevel] = 25,
            [questKeys.requiredRaces] = raceIDs.NONE,
            [questKeys.requiredClasses] = classIDs.NONE,
            [questKeys.objectivesText] = {"The helm of the Dragonslayer once belonged to a great commander who fell in battle. It is said his tormented soul still haunts the site of his passing."},
            [questKeys.objectives] = {nil,nil,{{209872}}},
        },
        [78133] = {
            [questKeys.name] = "Dragonslayer's Shield",
            [questKeys.startedBy] = {{210995}},
            [questKeys.finishedBy] = {{210995,}},
            [questKeys.requiredLevel] = 1,
            [questKeys.questLevel] = 25,
            [questKeys.requiredRaces] = raceIDs.NONE,
            [questKeys.requiredClasses] = classIDs.NONE,
            [questKeys.objectivesText] = {"The shield of the Dragonslayer is rumored to be held by an Orcish warlord. He stole it while raiding a human settlement."},
            [questKeys.objectives] = {nil,nil,{{209873}}},
        },
        [78134] = {
            [questKeys.name] = "Dragonslayer's Lance",
            [questKeys.startedBy] = {{210995}},
            [questKeys.finishedBy] = {{210995,}},
            [questKeys.requiredLevel] = 1,
            [questKeys.questLevel] = 25,
            [questKeys.requiredRaces] = raceIDs.NONE,
            [questKeys.requiredClasses] = classIDs.NONE,
            [questKeys.objectivesText] = {"The lance of the Dragonslayer has changed hands many times. Every now and then, rumor spreads of it appearing in black market arms deals. Perhaps the lance's current unsavory proprietor would be willing to part with it; for a price."},
            [questKeys.objectives] = {nil,nil,{{209874}}},
        },
        [78142] = {
            [questKeys.name] = "Bewitchments and Glamours",
            [questKeys.startedBy] = {{211033}},
            [questKeys.finishedBy] = {{211022,211033,}},
            [questKeys.requiredLevel] = 1,
            [questKeys.questLevel] = 20,
            [questKeys.requiredRaces] = raceIDs.NONE,
            [questKeys.requiredClasses] = classIDs.MAGE,
            [questKeys.objectivesText] = {"Have you brought something to add to our collection?"},
            [questKeys.objectives] = {nil,nil,{{209845}}},
        },
        [78143] = {
            [questKeys.name] = "Secrets of the Dreamers",
            [questKeys.startedBy] = {{211033}},
            [questKeys.finishedBy] = {{211022,211033,}},
            [questKeys.requiredLevel] = 1,
            [questKeys.questLevel] = 20,
            [questKeys.requiredRaces] = raceIDs.NONE,
            [questKeys.requiredClasses] = classIDs.MAGE,
            [questKeys.objectivesText] = {"Have you brought something to add to our collection?"},
            [questKeys.objectives] = {nil,nil,{{209846}}},
        },
        [78144] = {
            [questKeys.name] = "Alonso the Dragonslayer",
            [questKeys.startedBy] = {{210995}},
            [questKeys.finishedBy] = {{210995,}},
            [questKeys.requiredLevel] = 1,
            [questKeys.questLevel] = 25,
            [questKeys.requiredRaces] = raceIDs.NONE,
            [questKeys.requiredClasses] = classIDs.WARRIOR,
            [questKeys.objectivesText] = {"Accompany Alonso to slay the dragon."},
            [questKeys.objectives] = nil,
        },
        [78145] = {
            [questKeys.name] = "Arcanic Systems Manual",
            [questKeys.startedBy] = {{211033}},
            [questKeys.finishedBy] = {{211022,211033,}},
            [questKeys.requiredLevel] = 1,
            [questKeys.questLevel] = 20,
            [questKeys.requiredRaces] = raceIDs.NONE,
            [questKeys.requiredClasses] = classIDs.MAGE,
            [questKeys.objectivesText] = {"Have you brought something to add to our collection?"},
            [questKeys.objectives] = {nil,nil,{{209847}}},
        },
        [78146] = {
            [questKeys.name] = "Goaz Scrolls",
            [questKeys.startedBy] = {{211033}},
            [questKeys.finishedBy] = {{211022,211033,}},
            [questKeys.requiredLevel] = 1,
            [questKeys.questLevel] = 20,
            [questKeys.requiredRaces] = raceIDs.NONE,
            [questKeys.requiredClasses] = classIDs.MAGE,
            [questKeys.objectivesText] = {"Have you brought something to add to our collection?"},
            [questKeys.objectives] = {nil,nil,{{209848}}},
        },
        [78147] = {
            [questKeys.name] = "Crimes Against Anatomy",
            [questKeys.startedBy] = {{211033}},
            [questKeys.finishedBy] = {{211022,211033,}},
            [questKeys.requiredLevel] = 1,
            [questKeys.questLevel] = 20,
            [questKeys.requiredRaces] = raceIDs.NONE,
            [questKeys.requiredClasses] = classIDs.MAGE,
            [questKeys.objectivesText] = {"Have you brought something to add to our collection?"},
            [questKeys.objectives] = {nil,nil,{{209849}}},
        },
        [78148] = {
            [questKeys.name] = "Runes of the Sorceror-Kings",
            [questKeys.startedBy] = {{211033}},
            [questKeys.finishedBy] = {{211022,211033,}},
            [questKeys.requiredLevel] = 1,
            [questKeys.questLevel] = 20,
            [questKeys.requiredRaces] = raceIDs.NONE,
            [questKeys.requiredClasses] = classIDs.MAGE,
            [questKeys.objectivesText] = {"Have you brought something to add to our collection?"},
            [questKeys.objectives] = {nil,nil,{{209850}}},
        },
        [78149] = {
            [questKeys.name] = "Fury of the Land",
            [questKeys.startedBy] = {{211033}},
            [questKeys.finishedBy] = {{211022,211033,}},
            [questKeys.requiredLevel] = 1,
            [questKeys.questLevel] = 20,
            [questKeys.requiredRaces] = raceIDs.NONE,
            [questKeys.requiredClasses] = classIDs.MAGE,
            [questKeys.objectivesText] = {"Have you brought something to add to our collection?"},
            [questKeys.objectives] = {nil,nil,{{209851}}},
        },
        [78150] = {
            [questKeys.name] = "Friend of the Library",
            [questKeys.startedBy] = {{211033}},
            [questKeys.finishedBy] = {{211022,211033,}},
            [questKeys.requiredLevel] = 1,
            [questKeys.questLevel] = 20,
            [questKeys.requiredRaces] = raceIDs.NONE,
            [questKeys.requiredClasses] = classIDs.MAGE,
            [questKeys.objectivesText] = {"Thanks to your donations, the library is thriving.Please, take this."},
            [questKeys.objectives] = nil,
        },
        [78192] = {
            [questKeys.name] = "Secrets of the Light",
            [questKeys.startedBy] = {{211188}},
            [questKeys.finishedBy] = {{211188,}},
            [questKeys.requiredLevel] = 17,
            [questKeys.questLevel] = 20,
            [questKeys.requiredRaces] = raceIDs.ALL_ALLIANCE,
            [questKeys.requiredClasses] = classIDs.PRIEST,
            [questKeys.objectivesText] = {"Kill 7 Forsaken Herbalists and 9 Forsaken Seekers in northwest Ashenvale, then return to Maethra Slagheart in Darnassus."},
            [questKeys.objectives] = nil,
        },
        [78193] = {
            [questKeys.name] = "Secrets of the Light",
            [questKeys.startedBy] = {{211188}},
            [questKeys.finishedBy] = {{376,}},
            [questKeys.requiredLevel] = 17,
            [questKeys.questLevel] = 20,
            [questKeys.requiredRaces] = raceIDs.ALL_ALLIANCE,
            [questKeys.requiredClasses] = classIDs.PRIEST,
            [questKeys.objectivesText] = {"Travel to Stormwind City and speak to High Priestess Laurena in the Cathedral of Light."},
            [questKeys.objectives] = nil,
        },
        [78194] = {
            [questKeys.name] = "Secrets of Elune",
            [questKeys.startedBy] = {{11397}},
            [questKeys.finishedBy] = {{11397,}},
            [questKeys.requiredLevel] = 17,
            [questKeys.questLevel] = 20,
            [questKeys.requiredRaces] = raceIDs.ALL_ALLIANCE,
            [questKeys.requiredClasses] = classIDs.PRIEST,
            [questKeys.objectivesText] = {"Collect 10 Dire Wolf Paws from wolves in Duskwood."},
            [questKeys.objectives] = {nil,nil,{{210053}}},
        },
        [78195] = {
            [questKeys.name] = "Secrets of Elune",
            [questKeys.startedBy] = {{11397}},
            [questKeys.finishedBy] = {{211298,}},
            [questKeys.requiredLevel] = 17,
            [questKeys.questLevel] = 20,
            [questKeys.requiredRaces] = raceIDs.ALL_ALLIANCE,
            [questKeys.requiredClasses] = classIDs.PRIEST,
            [questKeys.objectivesText] = {"Bring the phial to Syrnoya at the Auberdine moonwell."},
            [questKeys.objectives] = nil,
        },
        [78196] = {
            [questKeys.name] = "Secrets of Undeath",
            [questKeys.startedBy] = {{211229}},
            [questKeys.finishedBy] = {{211229,}},
            [questKeys.requiredLevel] = 18,
            [questKeys.questLevel] = 22,
            [questKeys.requiredRaces] = raceIDs.ALL_HORDE,
            [questKeys.requiredClasses] = classIDs.PRIEST,
            [questKeys.objectivesText] = {"Collect 12 Shadeleaf from Shadethicket elementals in Ashenvale."},
            [questKeys.objectives] = {nil,nil,{{210045}}},
        },
        [78197] = {
            [questKeys.name] = "Secrets of Undeath",
            [questKeys.startedBy] = {{211229}},
            [questKeys.finishedBy] = {{6491,}},
            [questKeys.requiredLevel] = 18,
            [questKeys.questLevel] = 22,
            [questKeys.requiredRaces] = raceIDs.ALL_HORDE,
            [questKeys.requiredClasses] = classIDs.PRIEST,
            [questKeys.objectivesText] = {"Travel to Brill's graveyard in Tirisfal Glades and use the Tincture of Waking Death."},
            [questKeys.objectives] = nil,
        },
        [78198] = {
            [questKeys.name] = "Secrets of the Loa",
            [questKeys.startedBy] = {{211225}},
            [questKeys.finishedBy] = {{211225,}},
            [questKeys.requiredLevel] = 18,
            [questKeys.questLevel] = 23,
            [questKeys.requiredRaces] = raceIDs.ALL_HORDE,
            [questKeys.requiredClasses] = classIDs.PRIEST,
            [questKeys.objectivesText] = {"Collect 14 Hillsbrad Human Bones from humans in Hillsbrad Foothills, then return to Baj'ura in Undercity."},
            [questKeys.objectives] = {nil,nil,{{210055}}},
        },
        [78199] = {
            [questKeys.name] = "Secrets of the Loa",
            [questKeys.startedBy] = {{211225}},
            [questKeys.finishedBy] = nil,
            [questKeys.requiredLevel] = 18,
            [questKeys.questLevel] = 23,
            [questKeys.requiredRaces] = raceIDs.ALL_HORDE,
            [questKeys.requiredClasses] = classIDs.PRIEST,
            [questKeys.objectivesText] = {"Travel to the Echo Isles and use the offering at Bwonsamdi's shrine."},
            [questKeys.objectives] = nil,
        },
        [78229] = {
            [questKeys.name] = "Trial of The Owls",
            [questKeys.startedBy] = {{12042}},
            [questKeys.finishedBy] = {{12042,}},
            [questKeys.requiredLevel] = 1,
            [questKeys.questLevel] = 25,
            [questKeys.requiredRaces] = raceIDs.NONE,
            [questKeys.requiredClasses] = classIDs.DRUID,
            [questKeys.objectivesText] = {"Bring symbols of the three owls to Loganaar in Moonglade."},
            [questKeys.objectives] = {nil,nil,{{210044},{210043},{210026}}},
        },
        [78261] = {
            [questKeys.name] = "The Horn of Xelthos",
            [questKeys.startedBy] = nil,
            [questKeys.finishedBy] = nil,
            [questKeys.requiredLevel] = 1,
            [questKeys.questLevel] = 23,
            [questKeys.requiredRaces] = raceIDs.NONE,
            [questKeys.requiredClasses] = classIDs.ROGUE,
            [questKeys.objectivesText] = {"Find The Horn of Xelthos inside of Shadowfang Keep. Then, return it to C's dead drop near Pyrewood Village. You must complete the job alone."},
            [questKeys.objectives] = {nil,nil,{{210183}}},
        },
        [78265] = {
            [questKeys.name] = "Fish Oil",
            [questKeys.startedBy] = {{211653}},
            [questKeys.finishedBy] = {{211653,}},
            [questKeys.requiredLevel] = 20,
            [questKeys.questLevel] = 25,
            [questKeys.requiredRaces] = raceIDs.NONE,
            [questKeys.requiredClasses] = classIDs.NONE,
            [questKeys.objectivesText] = {"I'm going to need fish oil - and a lot of it!"},
            [questKeys.objectives] = {nil,nil,{{17058}}},
        },
        [78266] = {
            [questKeys.name] = "Dark Iron Ordinance",
            [questKeys.startedBy] = {{211653}},
            [questKeys.finishedBy] = {{211653,}},
            [questKeys.requiredLevel] = 20,
            [questKeys.questLevel] = 25,
            [questKeys.requiredRaces] = raceIDs.NONE,
            [questKeys.requiredClasses] = classIDs.NONE,
            [questKeys.objectivesText] = {"I'll need some Dark Iron Ordinance. Where are you going to find Dark Iron dwarves? That's your problem!"},
            [questKeys.objectives] = {nil,nil,{{210138}}},
        },
        [78267] = {
            [questKeys.name] = "Shredder Turbochargers",
            [questKeys.startedBy] = {{211653}},
            [questKeys.finishedBy] = {{211653,}},
            [questKeys.requiredLevel] = 20,
            [questKeys.questLevel] = 25,
            [questKeys.requiredRaces] = raceIDs.NONE,
            [questKeys.requiredClasses] = classIDs.NONE,
            [questKeys.objectivesText] = {"I'll need some of the Venture Company's Shredder Turbochargers. They're tightly coupled to the shredder systems, so you'll need special equipment to salvage them.No, I don't have that equipment."},
            [questKeys.objectives] = {nil,nil,{{210146}}},
        },
        [78270] = {
            [questKeys.name] = "Goblin Lockpicks",
            [questKeys.startedBy] = nil,
            [questKeys.finishedBy] = {{4086,}},
            [questKeys.requiredLevel] = 1,
            [questKeys.questLevel] = 23,
            [questKeys.requiredRaces] = raceIDs.NONE,
            [questKeys.requiredClasses] = classIDs.ROGUE,
            [questKeys.objectivesText] = {"Find The Horn of Xelthos inside of Shadowfang Keep. Then, return it to C's dead drop near Pyrewood Village."},
            [questKeys.objectives] = {nil,nil,{{210187}}},
        },
        [78277] = {
            [questKeys.name] = "A Token of Gratitude",
            [questKeys.startedBy] = {{1498}},
            [questKeys.finishedBy] = {{1498,}},
            [questKeys.requiredLevel] = 12,
            [questKeys.questLevel] = 25,
            [questKeys.requiredRaces] = raceIDs.ALL_HORDE,
            [questKeys.requiredClasses] = classIDs.MAGE,
            [questKeys.objectivesText] = {"It might have been a silly thing to do, but Thule, Gunthar and I were like family... brothers. We never expected our world to be torn apart, nor for Thule to side with the Lich King leaving Gunthar and myself to fight for our humanity... I can sense the taint of the scourge seeping into Thule's portion of the wand. It will forever be marred, corrupted by his betrayal, but alas I am not ready to let go... maybe with time.Please accept this token of knowledge as my final thanks."},
            [questKeys.objectives] = nil,
        },
        [78287] = {
            [questKeys.name] = "Let Me Make You An Offer",
            [questKeys.startedBy] = {{211653}},
            [questKeys.finishedBy] = {{8383,}},
            [questKeys.requiredLevel] = 20,
            [questKeys.questLevel] = 25,
            [questKeys.requiredRaces] = raceIDs.ALL_ALLIANCE,
            [questKeys.requiredClasses] = classIDs.NONE,
            [questKeys.objectivesText] = {"Take the Arms Shipment to Master Wood in Stormwind City."},
            [questKeys.objectives] = nil,
        },
        [78288] = {
            [questKeys.name] = "Let Me Make You An Offer",
            [questKeys.startedBy] = {{211653}},
            [questKeys.finishedBy] = {{3408,}},
            [questKeys.requiredLevel] = 20,
            [questKeys.questLevel] = 25,
            [questKeys.requiredRaces] = raceIDs.ALL_HORDE,
            [questKeys.requiredClasses] = classIDs.NONE,
            [questKeys.objectivesText] = {"Take the Arms Shipment to Zel'mak in Orgrimmar."},
            [questKeys.objectives] = nil,
        },
        [78297] = {
            [questKeys.name] = "You've Got Yourself A Deal",
            [questKeys.startedBy] = {{8383}},
            [questKeys.finishedBy] = {{211653,}},
            [questKeys.requiredLevel] = 20,
            [questKeys.questLevel] = 25,
            [questKeys.requiredRaces] = raceIDs.ALL_ALLIANCE,
            [questKeys.requiredClasses] = classIDs.NONE,
            [questKeys.objectivesText] = {"Return the Signed Procurement Contract to Grizzby in Ratchet."},
            [questKeys.objectives] = nil,
        },
        [78304] = {
            [questKeys.name] = "You've Got Yourself A Deal",
            [questKeys.startedBy] = {{3408}},
            [questKeys.finishedBy] = {{211653,}},
            [questKeys.requiredLevel] = 20,
            [questKeys.questLevel] = 25,
            [questKeys.requiredRaces] = raceIDs.ALL_HORDE,
            [questKeys.requiredClasses] = classIDs.NONE,
            [questKeys.objectivesText] = {"Return the Signed Procurement Contract to Grizzby in Ratchet."},
            [questKeys.objectives] = nil,
        },
        [78307] = {
            [questKeys.name] = "The Horn of Xelthos",
            [questKeys.startedBy] = nil,
            [questKeys.finishedBy] = nil,
            [questKeys.requiredLevel] = 1,
            [questKeys.questLevel] = 23,
            [questKeys.requiredRaces] = raceIDs.NONE,
            [questKeys.requiredClasses] = classIDs.ROGUE,
            [questKeys.objectivesText] = {"Log."},
            [questKeys.objectives] = nil,
        },
        [78506] = {
            [questKeys.name] = "Elemental Distress",
            [questKeys.startedBy] = {{12736}},
            [questKeys.finishedBy] = {{12736,}},
            [questKeys.requiredLevel] = 1,
            [questKeys.questLevel] = 25,
            [questKeys.requiredRaces] = raceIDs.ALL_HORDE,
            [questKeys.requiredClasses] = classIDs.SHAMAN,
            [questKeys.objectivesText] = {"Collect motes of elemental rage, and bring them to Je'neu Sancrea at Zoram'gar Outpost, Ashenvale."},
            [questKeys.objectives] = {nil,nil,{{210668},{210667},{210665}}},
        },
        [78537] = {
            [questKeys.name] = "Elixir of Insight",
            [questKeys.startedBy] = {{12736}},
            [questKeys.finishedBy] = {{12736,}},
            [questKeys.requiredLevel] = 1,
            [questKeys.questLevel] = 25,
            [questKeys.requiredRaces] = raceIDs.ALL_HORDE,
            [questKeys.requiredClasses] = classIDs.SHAMAN,
            [questKeys.objectivesText] = {"Bring an Elixir of Water Breathing and an Elixir of Wisdom to Je'neu Sancrea at Zoram'gar Outpost, Ashenvale."},
            [questKeys.objectives] = {nil,nil,{{5996},{3383}}},
        },
        [78561] = {
            [questKeys.name] = "Elixir of Insight",
            [questKeys.startedBy] = {{12736}},
            [questKeys.finishedBy] = {{12736,}},
            [questKeys.requiredLevel] = 1,
            [questKeys.questLevel] = 25,
            [questKeys.requiredRaces] = raceIDs.ALL_HORDE,
            [questKeys.requiredClasses] = classIDs.SHAMAN,
            [questKeys.objectivesText] = {"Drink the Elixir of Insight near the bonfire at Zoram'gar Outpost, and witness the vision it grants you."},
            [questKeys.objectives] = {nil,nil,{{210712}}},
        },
        [78575] = {
            [questKeys.name] = "Hirzek",
            [questKeys.startedBy] = {{12736}},
            [questKeys.finishedBy] = {{12736,}},
            [questKeys.requiredLevel] = 1,
            [questKeys.questLevel] = 25,
            [questKeys.requiredRaces] = raceIDs.ALL_HORDE,
            [questKeys.requiredClasses] = classIDs.SHAMAN,
            [questKeys.objectivesText] = {"Slay Hirzek at Blackthorn Ridge, Barrens, and bring his staff to Jen'neu Sancrea at Zoram'gar Outpost, Ashenvale."},
            [questKeys.objectives] = {nil,nil,{{210724}}},
        },
        [78611] = {
            [questKeys.name] = "A Waylaid Shipment",
            [questKeys.startedBy] = {{214101}},
            [questKeys.finishedBy] = {{213077,214070,214096,214098,214099,214101,}},
            [questKeys.requiredLevel] = 1,
            [questKeys.questLevel] = 8,
            [questKeys.requiredRaces] = raceIDs.NONE,
            [questKeys.requiredClasses] = classIDs.NONE,
            [questKeys.objectivesText] = {"The shipment's missing some items, but it will still be of some use. &nbsp;Thank you, &lt;name&gt;."},
            [questKeys.objectives] = nil,
        },
        [78612] = {
            [questKeys.name] = "A Full Shipment",
            [questKeys.startedBy] = {{214101}},
            [questKeys.finishedBy] = {{213077,214070,214096,214098,214099,214101,}},
            [questKeys.requiredLevel] = 1,
            [questKeys.questLevel] = 9,
            [questKeys.requiredRaces] = raceIDs.NONE,
            [questKeys.requiredClasses] = classIDs.NONE,
            [questKeys.objectivesText] = {"Do you have something for me?"},
            [questKeys.objectives] = {nil,nil,{{211365}}},
        },
        [78680] = {
            [questKeys.name] = "Rumors Abound",
            [questKeys.startedBy] = {{6247}},
            [questKeys.finishedBy] = {{6247,}},
            [questKeys.requiredLevel] = 20,
            [questKeys.questLevel] = 25,
            [questKeys.requiredRaces] = raceIDs.NONE,
            [questKeys.requiredClasses] = classIDs.WARLOCK,
            [questKeys.objectivesText] = {"Not much is known about the location of these shattered weapon fragments, save that they are both in the possession of once great mages held up in towers of importance. One is said to be located here to the north on Kalimdor, while the other is nestled near the heart of the Eastern Kingdoms.See if the rumors are true... Search for the two missing halves of this weapon and bring them to me."},
            [questKeys.objectives] = {nil,nil,{{210765},{210763}}},
        },
        [78681] = {
            [questKeys.name] = "The Conjuring",
            [questKeys.startedBy] = {{6247}},
            [questKeys.finishedBy] = nil,
            [questKeys.requiredLevel] = 20,
            [questKeys.questLevel] = 28,
            [questKeys.requiredRaces] = raceIDs.NONE,
            [questKeys.requiredClasses] = classIDs.WARLOCK,
            [questKeys.objectivesText] = {"Collect 10 Blood of the Legion and perform the ritual to summon Des'Altek to trap its soul once again."},
            [questKeys.objectives] = {nil,nil,{{210966}}},
        },
        [78684] = {
            [questKeys.name] = "Mysterious Traveler",
            [questKeys.startedBy] = {{213444}},
            [questKeys.finishedBy] = {{6247,}},
            [questKeys.requiredLevel] = 20,
            [questKeys.questLevel] = 28,
            [questKeys.requiredRaces] = raceIDs.NONE,
            [questKeys.requiredClasses] = classIDs.NONE,
            [questKeys.objectivesText] = {"Meet with Doan Karhan and the Mysterious Traveler in the Barrens."},
            [questKeys.objectives] = nil,
        },
        [78702] = {
            [questKeys.name] = "Raszel Ander",
            [questKeys.startedBy] = {{6247}},
            [questKeys.finishedBy] = {{6247,}},
            [questKeys.requiredLevel] = 20,
            [questKeys.questLevel] = 28,
            [questKeys.requiredRaces] = raceIDs.NONE,
            [questKeys.requiredClasses] = classIDs.NONE,
            [questKeys.objectivesText] = {"Raszel was a friend... One I thought I had lost long ago, from a different time... We were young apprentices back then... Much has changed.The result of the ritual might have been a setback, but I believe we can still reform the weapon.Raszel and I have much to discuss, together we will come up with a plan. I'll send word once we know how to move forward.In the meantime, take this. It seems like something you might be interested in."},
            [questKeys.objectives] = nil,
        },
        [78823] = {
            [questKeys.name] = "Terror of the Desert Skies",
            [questKeys.startedBy] = nil,
            [questKeys.finishedBy] = {{715,}},
            [questKeys.requiredLevel] = 26,
            [questKeys.questLevel] = 40,
            [questKeys.requiredRaces] = raceIDs.NONE,
            [questKeys.requiredClasses] = classIDs.HUNTER,
            [questKeys.objectivesText] = {"Bring the Primitive Drawing to Hemet Nesingwary in Stranglethorn Vale."},
            [questKeys.objectives] = nil,
        },
        [78830] = {
            [questKeys.name] = "Terror of the Desert Skies",
            [questKeys.startedBy] = {{715}},
            [questKeys.finishedBy] = {{715,}},
            [questKeys.requiredLevel] = 26,
            [questKeys.questLevel] = 40,
            [questKeys.requiredRaces] = raceIDs.NONE,
            [questKeys.requiredClasses] = classIDs.HUNTER,
            [questKeys.objectivesText] = {"Get a Crimson Trophy Quill from Gharrik in the Badlands. Then, return to Hemet Nesingwary in Stranglethorn Vale."},
            [questKeys.objectives] = {nil,nil,{{211293},{211272}}},
        },
        [78872] = {
            [questKeys.name] = "A Full Shipment",
            [questKeys.startedBy] = {{214101}},
            [questKeys.finishedBy] = {{213077,214070,214096,214098,214099,214101,}},
            [questKeys.requiredLevel] = 1,
            [questKeys.questLevel] = 12,
            [questKeys.requiredRaces] = raceIDs.NONE,
            [questKeys.requiredClasses] = classIDs.NONE,
            [questKeys.objectivesText] = {"Do you have something for me?"},
            [questKeys.objectives] = {nil,nil,{{211367}}},
        },
        [78909] = {
            [questKeys.name] = "Shifting Scale Talisman",
            [questKeys.startedBy] = {{214208}},
            [questKeys.finishedBy] = {{214208,}},
            [questKeys.requiredLevel] = 25,
            [questKeys.questLevel] = 25,
            [questKeys.requiredRaces] = raceIDs.NONE,
            [questKeys.requiredClasses] = classIDs.NONE,
            [questKeys.objectivesText] = {"Bring N'ora Anyheart the following materials alongside the Handful of Shifting Scales to complete the talisman: A satchel of Strange Dust, five Greater Magic Essence, 2 Small Glimmering Shards and five gold pieces."},
            [questKeys.objectives] = {nil,nil,{{10940},{10939},{211419},{10978}}},
        },
        [78914] = {
            [questKeys.name] = "Soul Vessel",
            [questKeys.startedBy] = {{213445}},
            [questKeys.finishedBy] = {{215850,}},
            [questKeys.requiredLevel] = 30,
            [questKeys.questLevel] = 40,
            [questKeys.requiredRaces] = raceIDs.NONE,
            [questKeys.requiredClasses] = classIDs.WARLOCK,
            [questKeys.objectivesText] = {"Now that we have a way to weaken the demon we need a vessel to bind them within. The Burning Blade have overrun ancient elven ruins in southern Desolace, using it as a staging ground to summon demons to Azeroth. Once you have found a Soul Vessel meet us in Desolace, there we will complete the ritual."},
            [questKeys.objectives] = {nil,nil,{{211427}}},
        },
        [78916] = {
            [questKeys.name] = "The Heart of the Void",
            [questKeys.startedBy] = nil,
            [questKeys.finishedBy] = {{4783,}},
            [questKeys.requiredLevel] = 25,
            [questKeys.questLevel] = 25,
            [questKeys.requiredRaces] = raceIDs.ALL_ALLIANCE,
            [questKeys.requiredClasses] = classIDs.NONE,
            [questKeys.objectivesText] = {"Bring the Blackfathom Pearl to Dawnwatcher Selgorm in Darnassus."},
            [questKeys.objectives] = nil,
        },
        [78917] = {
            [questKeys.name] = "The Heart of the Void",
            [questKeys.startedBy] = nil,
            [questKeys.finishedBy] = {{9087,}},
            [questKeys.requiredLevel] = 25,
            [questKeys.questLevel] = 25,
            [questKeys.requiredRaces] = raceIDs.ALL_HORDE,
            [questKeys.requiredClasses] = classIDs.NONE,
            [questKeys.objectivesText] = {"Bring the Blackfathom Pearl to Bashana Runetotem in Thunder Bluff."},
            [questKeys.objectives] = nil,
        },
        [78920] = {
            [questKeys.name] = "Baron Aquanis",
            [questKeys.startedBy] = nil,
            [questKeys.finishedBy] = {{12736,}},
            [questKeys.requiredLevel] = 25,
            [questKeys.questLevel] = 27,
            [questKeys.requiredRaces] = raceIDs.ALL_HORDE,
            [questKeys.requiredClasses] = classIDs.NONE,
            [questKeys.objectivesText] = {"Bring the Strange Water Globe to Je'neu Sancrea at Zoram'gar Outpost, Ashenvale."},
            [questKeys.objectives] = nil,
        },
        [78921] = {
            [questKeys.name] = "Blackfathom Villainy",
            [questKeys.startedBy] = {{4787}},
            [questKeys.finishedBy] = {{4783,}},
            [questKeys.requiredLevel] = 25,
            [questKeys.questLevel] = 27,
            [questKeys.requiredRaces] = raceIDs.ALL_ALLIANCE,
            [questKeys.requiredClasses] = classIDs.NONE,
            [questKeys.objectivesText] = {"Bring the head of Twilight Lord Kelris to Dawnwatcher Selgorm in Darnassus."},
            [questKeys.objectives] = {nil,nil,{{5881}}},
        },
        [78922] = {
            [questKeys.name] = "Blackfathom Villainy",
            [questKeys.startedBy] = {{4787}},
            [questKeys.finishedBy] = {{9087,}},
            [questKeys.requiredLevel] = 25,
            [questKeys.questLevel] = 27,
            [questKeys.requiredRaces] = raceIDs.ALL_HORDE,
            [questKeys.requiredClasses] = classIDs.NONE,
            [questKeys.objectivesText] = {"Bring the head of Twilight Lord Kelris to Bashana Runetotem in Thunder Bluff."},
            [questKeys.objectives] = {nil,nil,{{5881}}},
        },
        [78923] = {
            [questKeys.name] = "Knowledge in the Deeps",
            [questKeys.startedBy] = {{2786}},
            [questKeys.finishedBy] = {{2786,}},
            [questKeys.requiredLevel] = 25,
            [questKeys.questLevel] = 27,
            [questKeys.requiredRaces] = raceIDs.ALL_ALLIANCE,
            [questKeys.requiredClasses] = classIDs.NONE,
            [questKeys.objectivesText] = {"Bring the Lorgalis Manuscript to Gerrig Bonegrip in the Forlorn Cavern in Ironforge."},
            [questKeys.objectives] = {nil,nil,{{5359}}},
        },
        [78925] = {
            [questKeys.name] = "Twilight Falls",
            [questKeys.startedBy] = {{4784}},
            [questKeys.finishedBy] = {{4784,}},
            [questKeys.requiredLevel] = 25,
            [questKeys.questLevel] = 27,
            [questKeys.requiredRaces] = raceIDs.ALL_ALLIANCE,
            [questKeys.requiredClasses] = classIDs.NONE,
            [questKeys.objectivesText] = {"Bring 10 Twilight Pendants to Argent Guard Manados in Darnassus."},
            [questKeys.objectives] = {nil,nil,{{5879}}},
        },
        [78926] = {
            [questKeys.name] = "Researching the Corruption",
            [questKeys.startedBy] = {{8997}},
            [questKeys.finishedBy] = {{8997,}},
            [questKeys.requiredLevel] = 25,
            [questKeys.questLevel] = 27,
            [questKeys.requiredRaces] = raceIDs.ALL_ALLIANCE,
            [questKeys.requiredClasses] = classIDs.NONE,
            [questKeys.objectivesText] = {"Gershala Nightwhisper in Auberdine wants 8 Corrupt Brain stems."},
            [questKeys.objectives] = {nil,nil,{{5952}}},
        },
        [78927] = {
            [questKeys.name] = "Allegiance to the Old Gods",
            [questKeys.startedBy] = {{12736}},
            [questKeys.finishedBy] = {{12736,}},
            [questKeys.requiredLevel] = 25,
            [questKeys.questLevel] = 27,
            [questKeys.requiredRaces] = raceIDs.ALL_HORDE,
            [questKeys.requiredClasses] = classIDs.NONE,
            [questKeys.objectivesText] = {"Kill Lorgus Jett in Blackfathom Deeps and then return to Je'neu Sancrea in Ashenvale."},
            [questKeys.objectives] = nil,
        },
        [78994] = {
            [questKeys.name] = "A Solid Foundation",
            [questKeys.startedBy] = {{213445}},
            [questKeys.finishedBy] = {{213445,}},
            [questKeys.requiredLevel] = 30,
            [questKeys.questLevel] = 40,
            [questKeys.requiredRaces] = raceIDs.NONE,
            [questKeys.requiredClasses] = classIDs.WARLOCK,
            [questKeys.objectivesText] = {"The Emerald Dragons protect several portals to the Emerald Dream throughout Azeroth. One of these locations surely has what we need.Once you've found a Bough of Shadows return with haste."},
            [questKeys.objectives] = {nil,nil,{{211426}}},
        },
        [79007] = {
            [questKeys.name] = "...and that note you found",
            [questKeys.startedBy] = nil,
            [questKeys.finishedBy] = nil,
            [questKeys.requiredLevel] = 14,
            [questKeys.questLevel] = 40,
            [questKeys.requiredRaces] = raceIDs.ALL_HORDE,
            [questKeys.requiredClasses] = classIDs.NONE,
            [questKeys.objectivesText] = {"Charred remains of the note serve as your only guide."},
            [questKeys.objectives] = nil,
        },
        [79008] = {
            [questKeys.name] = "...and that note you found",
            [questKeys.startedBy] = nil,
            [questKeys.finishedBy] = nil,
            [questKeys.requiredLevel] = 14,
            [questKeys.questLevel] = 40,
            [questKeys.requiredRaces] = raceIDs.ALL_ALLIANCE,
            [questKeys.requiredClasses] = classIDs.NONE,
            [questKeys.objectivesText] = {"Charred remains of the note serve as your only guide."},
            [questKeys.objectives] = nil,
        },
        [79077] = {
            [questKeys.name] = "Sharing the Faith",
            [questKeys.startedBy] = {{1212}},
            [questKeys.finishedBy] = {{1212,}},
            [questKeys.requiredLevel] = 5,
            [questKeys.questLevel] = 5,
            [questKeys.requiredRaces] = raceIDs.ALL_ALLIANCE,
            [questKeys.requiredClasses] = classIDs.PRIEST,
            [questKeys.objectivesText] = {"Meditate on the Light, then pray with the kneeling elf to share your meditations."},
            [questKeys.objectives] = nil,
        },
        [79078] = {
            [questKeys.name] = "Sharing the Faith",
            [questKeys.startedBy] = {{4092}},
            [questKeys.finishedBy] = {{4092,}},
            [questKeys.requiredLevel] = 5,
            [questKeys.questLevel] = 5,
            [questKeys.requiredRaces] = raceIDs.ALL_ALLIANCE,
            [questKeys.requiredClasses] = classIDs.PRIEST,
            [questKeys.objectivesText] = {"Meditate on Elune, then pray with the kneeling human to share your meditations."},
            [questKeys.objectives] = nil,
        },
        [79079] = {
            [questKeys.name] = "Sharing the Faith",
            [questKeys.startedBy] = {{6018}},
            [questKeys.finishedBy] = {{6018,}},
            [questKeys.requiredLevel] = 5,
            [questKeys.questLevel] = 5,
            [questKeys.requiredRaces] = raceIDs.ALL_HORDE,
            [questKeys.requiredClasses] = classIDs.PRIEST,
            [questKeys.objectivesText] = {"Meditate on the Loa, then pray with the kneeling Forsaken to share your meditations."},
            [questKeys.objectives] = nil,
        },
        [79080] = {
            [questKeys.name] = "Sharing the Faith",
            [questKeys.startedBy] = {{4607}},
            [questKeys.finishedBy] = {{4607,}},
            [questKeys.requiredLevel] = 5,
            [questKeys.questLevel] = 5,
            [questKeys.requiredRaces] = raceIDs.ALL_HORDE,
            [questKeys.requiredClasses] = classIDs.PRIEST,
            [questKeys.objectivesText] = {"Meditate on undeath, then pray with the kneeling troll to share your meditations."},
            [questKeys.objectives] = nil,
        },
        [79090] = {
            [questKeys.name] = "Repelling Invaders",
            [questKeys.startedBy] = nil,
            [questKeys.finishedBy] = {{212970,217707,}},
            [questKeys.requiredLevel] = 18,
            [questKeys.questLevel] = 25,
            [questKeys.requiredRaces] = raceIDs.ALL_ALLIANCE,
            [questKeys.requiredClasses] = classIDs.NONE,
            [questKeys.objectivesText] = {"Bring the Warsong Outrider Mark to Felore Moonray, Priestess of the Moon, at the Moonwell base in Ashenvale."},
            [questKeys.objectives] = nil,
        },
        [79091] = {
            [questKeys.name] = "Archmage Antonidas: The Unabridged Autobiography",
            [questKeys.startedBy] = {{211033}},
            [questKeys.finishedBy] = {{211033,}},
            [questKeys.requiredLevel] = 1,
            [questKeys.questLevel] = 20,
            [questKeys.requiredRaces] = raceIDs.ALL_ALLIANCE,
            [questKeys.requiredClasses] = classIDs.MAGE,
            [questKeys.objectivesText] = {"Have you brought something to add to our collection?"},
            [questKeys.objectives] = {nil,nil,{{203754}}},
        },
        [79092] = {
            [questKeys.name] = "Archmage Theocritus's Research Journal",
            [questKeys.startedBy] = {{211033}},
            [questKeys.finishedBy] = {{211033,}},
            [questKeys.requiredLevel] = 1,
            [questKeys.questLevel] = 20,
            [questKeys.requiredRaces] = raceIDs.ALL_ALLIANCE,
            [questKeys.requiredClasses] = classIDs.MAGE,
            [questKeys.objectivesText] = {"Have you brought something to add to our collection?"},
            [questKeys.objectives] = {nil,nil,{{203755}}},
        },
        [79093] = {
            [questKeys.name] = "Rumi of Gnomeregan: The Collected Works",
            [questKeys.startedBy] = {{211033}},
            [questKeys.finishedBy] = {{211033,}},
            [questKeys.requiredLevel] = 1,
            [questKeys.questLevel] = 20,
            [questKeys.requiredRaces] = raceIDs.ALL_ALLIANCE,
            [questKeys.requiredClasses] = classIDs.MAGE,
            [questKeys.objectivesText] = {"Have you brought something to add to our collection?"},
            [questKeys.objectives] = {nil,nil,{{208860}}},
        },
        [79094] = {
            [questKeys.name] = "The Lessons of Ta'zo",
            [questKeys.startedBy] = {{211022}},
            [questKeys.finishedBy] = {{211022,}},
            [questKeys.requiredLevel] = 1,
            [questKeys.questLevel] = 20,
            [questKeys.requiredRaces] = raceIDs.ALL_HORDE,
            [questKeys.requiredClasses] = classIDs.MAGE,
            [questKeys.objectivesText] = {"Have you brought something to add to our collection?"},
            [questKeys.objectives] = {nil,nil,{{207972}}},
        },
        [79095] = {
            [questKeys.name] = "The Apothecary's Metaphysical Primer",
            [questKeys.startedBy] = {{211022}},
            [questKeys.finishedBy] = {{211022,}},
            [questKeys.requiredLevel] = 1,
            [questKeys.questLevel] = 20,
            [questKeys.requiredRaces] = raceIDs.ALL_HORDE,
            [questKeys.requiredClasses] = classIDs.MAGE,
            [questKeys.objectivesText] = {"Have you brought something to add to our collection?"},
            [questKeys.objectives] = {nil,nil,{{208185}}},
        },
        [79096] = {
            [questKeys.name] = "Ataeric: On Arcane Curiosities",
            [questKeys.startedBy] = {{211022}},
            [questKeys.finishedBy] = {{211022,}},
            [questKeys.requiredLevel] = 1,
            [questKeys.questLevel] = 20,
            [questKeys.requiredRaces] = raceIDs.ALL_HORDE,
            [questKeys.requiredClasses] = classIDs.MAGE,
            [questKeys.objectivesText] = {"Have you brought something to add to our collection?"},
            [questKeys.objectives] = {nil,nil,{{210177}}},
        },
        [79097] = {
            [questKeys.name] = "Baxtan: On Destructive Magics",
            [questKeys.startedBy] = {{211033}},
            [questKeys.finishedBy] = {{211022,211033,}},
            [questKeys.requiredLevel] = 1,
            [questKeys.questLevel] = 20,
            [questKeys.requiredRaces] = raceIDs.NONE,
            [questKeys.requiredClasses] = classIDs.MAGE,
            [questKeys.objectivesText] = {"Have you brought something to add to our collection?"},
            [questKeys.objectives] = {nil,nil,{{208800}}},
        },
        [79098] = {
            [questKeys.name] = "Clear the Forest!",
            [questKeys.startedBy] = nil,
            [questKeys.finishedBy] = {{212969,217706,}},
            [questKeys.requiredLevel] = 18,
            [questKeys.questLevel] = 25,
            [questKeys.requiredRaces] = raceIDs.ALL_HORDE,
            [questKeys.requiredClasses] = classIDs.NONE,
            [questKeys.objectivesText] = {"Bring the Silverwing Sentinel Charm to Kazragore, Far Seer, at the Bonfire base in Ashenvale."},
            [questKeys.objectives] = nil,
        },
        [79099] = {
            [questKeys.name] = "Baron Aquanis",
            [questKeys.startedBy] = {{214876}},
            [questKeys.finishedBy] = {{214876,}},
            [questKeys.requiredLevel] = 25,
            [questKeys.questLevel] = 27,
            [questKeys.requiredRaces] = raceIDs.ALL_ALLIANCE,
            [questKeys.requiredClasses] = classIDs.NONE,
            [questKeys.objectivesText] = {"Bring the Strange Water Globe to Davidus Voidstar in Auberdine, Darkshore."},
            [questKeys.objectives] = {nil,nil,{{211818}}},
        },
        [79100] = {
            [questKeys.name] = "A Waylaid Shipment",
            [questKeys.startedBy] = {{214101}},
            [questKeys.finishedBy] = {{213077,214070,214096,214098,214099,214101,}},
            [questKeys.requiredLevel] = 1,
            [questKeys.questLevel] = 15,
            [questKeys.requiredRaces] = raceIDs.NONE,
            [questKeys.requiredClasses] = classIDs.NONE,
            [questKeys.objectivesText] = {"The shipment's missing some items, but it will still be of some use. &nbsp;Thank you, &lt;name&gt;."},
            [questKeys.objectives] = nil,
        },
        [79101] = {
            [questKeys.name] = "A Full Shipment",
            [questKeys.startedBy] = {{214101}},
            [questKeys.finishedBy] = {{213077,214070,214096,214098,214099,214101,}},
            [questKeys.requiredLevel] = 1,
            [questKeys.questLevel] = 18,
            [questKeys.requiredRaces] = raceIDs.NONE,
            [questKeys.requiredClasses] = classIDs.NONE,
            [questKeys.objectivesText] = {"Do you have something for me?"},
            [questKeys.objectives] = {nil,nil,{{211839}}},
        },
        [79102] = {
            [questKeys.name] = "A Full Shipment",
            [questKeys.startedBy] = {{214101}},
            [questKeys.finishedBy] = {{213077,214070,214096,214098,214099,214101,}},
            [questKeys.requiredLevel] = 1,
            [questKeys.questLevel] = 22,
            [questKeys.requiredRaces] = raceIDs.NONE,
            [questKeys.requiredClasses] = classIDs.NONE,
            [questKeys.objectivesText] = {"Do you have something for me?"},
            [questKeys.objectives] = {nil,nil,{{211840}}},
        },
        [79103] = {
            [questKeys.name] = "A Full Shipment",
            [questKeys.startedBy] = {{214101}},
            [questKeys.finishedBy] = {{213077,214070,214096,214098,214099,214101,}},
            [questKeys.requiredLevel] = 1,
            [questKeys.questLevel] = 25,
            [questKeys.requiredRaces] = raceIDs.NONE,
            [questKeys.requiredClasses] = classIDs.NONE,
            [questKeys.objectivesText] = {"Do you have something for me?"},
            [questKeys.objectives] = {nil,nil,{{211841}}},
        },
        [79192] = {
            [questKeys.name] = "Stepping Stones",
            [questKeys.startedBy] = nil,
            [questKeys.finishedBy] = nil,
            [questKeys.requiredLevel] = 14,
            [questKeys.questLevel] = 40,
            [questKeys.requiredRaces] = raceIDs.ALL_ALLIANCE,
            [questKeys.requiredClasses] = classIDs.NONE,
            [questKeys.objectivesText] = {"You tear the note from the plank and read the scrawled writing."},
            [questKeys.objectives] = nil,
        },
        [79229] = {
            [questKeys.name] = "Highway Robbery",
            [questKeys.startedBy] = {{11438}},
            [questKeys.finishedBy] = {{11438,}},
            [questKeys.requiredLevel] = 30,
            [questKeys.questLevel] = 40,
            [questKeys.requiredRaces] = raceIDs.NONE,
            [questKeys.requiredClasses] = classIDs.NONE,
            [questKeys.objectivesText] = {"Find someone in Desolace who knows about the pillaged campsite."},
            [questKeys.objectives] = nil,
        },
        [79235] = {
            [questKeys.name] = "On the Lam",
            [questKeys.startedBy] = {{11438}},
            [questKeys.finishedBy] = {{215643,}},
            [questKeys.requiredLevel] = 30,
            [questKeys.questLevel] = 40,
            [questKeys.requiredRaces] = raceIDs.NONE,
            [questKeys.requiredClasses] = classIDs.NONE,
            [questKeys.objectivesText] = {"Find one of the Desolace marauders."},
            [questKeys.objectives] = nil,
        },
        [79236] = {
            [questKeys.name] = "Cherry for Your Thoughts?",
            [questKeys.startedBy] = {{215643}},
            [questKeys.finishedBy] = {{215643,}},
            [questKeys.requiredLevel] = 30,
            [questKeys.questLevel] = 40,
            [questKeys.requiredRaces] = raceIDs.NONE,
            [questKeys.requiredClasses] = classIDs.NONE,
            [questKeys.objectivesText] = {"Bring a Cherry Grog to Tokal, in Booty Bay, to hear the rest of her story."},
            [questKeys.objectives] = {nil,nil,{{4600}}},
        },
        [79242] = {
            [questKeys.name] = "No Honor Among Thieves",
            [questKeys.startedBy] = {{215643}},
            [questKeys.finishedBy] = nil,
            [questKeys.requiredLevel] = 30,
            [questKeys.questLevel] = 40,
            [questKeys.requiredRaces] = raceIDs.NONE,
            [questKeys.requiredClasses] = classIDs.NONE,
            [questKeys.objectivesText] = {"Find Illari Duskfeather, near Arathi Highlands, and get access to her cache of stolen loot."},
            [questKeys.objectives] = {nil,nil,{{212347}}},
        },
        [79482] = {
            [questKeys.name] = "Stolen Winter Veil Treats",
            [questKeys.startedBy] = {{216902}},
            [questKeys.finishedBy] = {{216915,}},
            [questKeys.requiredLevel] = 25,
            [questKeys.questLevel] = 60,
            [questKeys.requiredRaces] = raceIDs.ALL_ALLIANCE,
            [questKeys.requiredClasses] = classIDs.NONE,
            [questKeys.objectivesText] = {"Locate the Smokywood Pastures investigator that has gone missing in the snowy regions of the Alterac Mountains."},
            [questKeys.objectives] = nil,
        },
        [79483] = {
            [questKeys.name] = "Stolen Winter Veil Treats",
            [questKeys.startedBy] = {{216924}},
            [questKeys.finishedBy] = {{216915,}},
            [questKeys.requiredLevel] = 25,
            [questKeys.questLevel] = 60,
            [questKeys.requiredRaces] = raceIDs.ALL_HORDE,
            [questKeys.requiredClasses] = classIDs.NONE,
            [questKeys.objectivesText] = {"Locate the Smokywood Pastures investigator that has gone missing in the snowy regions of the Alterac Mountains."},
            [questKeys.objectives] = nil,
        },
        [79484] = {
            [questKeys.name] = "You're a Mean One...",
            [questKeys.startedBy] = {{216915}},
            [questKeys.finishedBy] = {{216902,}},
            [questKeys.requiredLevel] = 25,
            [questKeys.questLevel] = 60,
            [questKeys.requiredRaces] = raceIDs.ALL_ALLIANCE,
            [questKeys.requiredClasses] = classIDs.NONE,
            [questKeys.objectivesText] = {"Locate and return the Stolen Treats to Wulmort Jinglepocket in Ironforge.  It was last thought to be in the possession of the Abominable Greench, found somewhere in the snowy regions of the Alterac Mountains."},
            [questKeys.objectives] = {nil,nil,{{17662}}},
        },
        [79485] = {
            [questKeys.name] = "You're a Mean One...",
            [questKeys.startedBy] = {{216915}},
            [questKeys.finishedBy] = {{216924,}},
            [questKeys.requiredLevel] = 25,
            [questKeys.questLevel] = 60,
            [questKeys.requiredRaces] = raceIDs.ALL_HORDE,
            [questKeys.requiredClasses] = classIDs.NONE,
            [questKeys.objectivesText] = {"Locate and return the Stolen Treats to Kaymard Copperpinch in Orgrimmar.  It was last thought to be in the possession of the Abominable Greench, found somewhere in the snowy regions of the Alterac Mountains."},
            [questKeys.objectives] = {nil,nil,{{17662}}},
        },
        [79486] = {
            [questKeys.name] = "A Smokywood Pastures' Thank You!",
            [questKeys.startedBy] = {{216902}},
            [questKeys.finishedBy] = {{13444,}},
            [questKeys.requiredLevel] = 25,
            [questKeys.questLevel] = 60,
            [questKeys.requiredRaces] = raceIDs.ALL_ALLIANCE,
            [questKeys.requiredClasses] = classIDs.NONE,
            [questKeys.objectivesText] = {"Speak with Greatfather Winter in Ironforge."},
            [questKeys.objectives] = nil,
        },
        [79487] = {
            [questKeys.name] = "A Smokywood Pastures' Thank You!",
            [questKeys.startedBy] = {{216924}},
            [questKeys.finishedBy] = {{13445,}},
            [questKeys.requiredLevel] = 25,
            [questKeys.questLevel] = 60,
            [questKeys.requiredRaces] = raceIDs.ALL_HORDE,
            [questKeys.requiredClasses] = classIDs.NONE,
            [questKeys.objectivesText] = {"Speak with Great-father Winter in Orgrimmar."},
            [questKeys.objectives] = nil,
        },
        [79492] = {
            [questKeys.name] = "Metzen the Reindeer",
            [questKeys.startedBy] = {{216902}},
            [questKeys.finishedBy] = {{216902,}},
            [questKeys.requiredLevel] = 25,
            [questKeys.questLevel] = 60,
            [questKeys.requiredRaces] = raceIDs.ALL_ALLIANCE,
            [questKeys.requiredClasses] = classIDs.NONE,
            [questKeys.objectivesText] = {"Find Metzen the Reindeer.  Use the notes provided to you for clues as to where he is being held.When you find Metzen, have the Pouch of Reindeer Dust in your possession so you can sprinkle some of the dust on him; this should free Metzen from his bonds of captivity.Return the Pouch of Reindeer Dust to Wulmort Jinglepocket in Ironforge once Metzen is freed."},
            [questKeys.objectives] = {nil,nil,{{21211},{21315}}},
        },
        [79495] = {
            [questKeys.name] = "Metzen the Reindeer",
            [questKeys.startedBy] = {{216924}},
            [questKeys.finishedBy] = {{216924,}},
            [questKeys.requiredLevel] = 25,
            [questKeys.questLevel] = 60,
            [questKeys.requiredRaces] = raceIDs.ALL_HORDE,
            [questKeys.requiredClasses] = classIDs.NONE,
            [questKeys.objectivesText] = {"Find Metzen the Reindeer.  Use the notes provided to you for clues as to where he is being held.When you find Metzen, have the Pouch of Reindeer Dust in your possession so you can sprinkle some of the dust on him; this should free Metzen from his bonds of captivity.Return the Pouch of Reindeer Dust to Kaymard Copperpinch in Orgrimmar once Metzen is freed."},
            [questKeys.objectives] = {nil,nil,{{21211},{21315}}},
        },
        [79535] = {
            [questKeys.name] = "Basilisks: Should Petrification be Feared?",
            [questKeys.startedBy] = {{211033}},
            [questKeys.finishedBy] = {{211022,211033,}},
            [questKeys.requiredLevel] = 1,
            [questKeys.questLevel] = 35,
            [questKeys.requiredRaces] = raceIDs.NONE,
            [questKeys.requiredClasses] = classIDs.MAGE,
            [questKeys.objectivesText] = {"Have you brought something to add to our collection?"},
            [questKeys.objectives] = {nil,nil,{{213165}}},
        },
        [79536] = {
            [questKeys.name] = "Greater Friend of the Library",
            [questKeys.startedBy] = {{211033}},
            [questKeys.finishedBy] = {{211022,211033,}},
            [questKeys.requiredLevel] = 1,
            [questKeys.questLevel] = 35,
            [questKeys.requiredRaces] = raceIDs.NONE,
            [questKeys.requiredClasses] = classIDs.MAGE,
            [questKeys.objectivesText] = {"Thanks to your donations, the library is thriving.Please, take this."},
            [questKeys.objectives] = nil,
        },
        [79588] = {
            [questKeys.name] = "Small Furry Paws",
            [questKeys.startedBy] = {{14829}},
            [questKeys.finishedBy] = {{14829,}},
            [questKeys.requiredLevel] = 1,
            [questKeys.questLevel] = 60,
            [questKeys.requiredRaces] = raceIDs.NONE,
            [questKeys.requiredClasses] = classIDs.NONE,
            [questKeys.objectivesText] = {"The first lesson in drawing a crowd is: lure them with gadgets and trinkets! &nbsp;Can you help me?I need small furry paws to use for prizes. &nbsp;You can find those on the cats of the Barrens or Darkshore....Bring me some paws and I'll trade you a Darkmoon Faire ticket for them."},
            [questKeys.objectives] = {nil,nil,{{5134}}},
        },
        [79589] = {
            [questKeys.name] = "Torn Bear Pelts",
            [questKeys.startedBy] = {{14829}},
            [questKeys.finishedBy] = {{14829,}},
            [questKeys.requiredLevel] = 10,
            [questKeys.questLevel] = 60,
            [questKeys.requiredRaces] = raceIDs.NONE,
            [questKeys.requiredClasses] = classIDs.NONE,
            [questKeys.objectivesText] = {"Children love toys! &nbsp;And no matter what race, I've found that all children love furry, plushy toys made from torn bear pelts!You can get those pelts from the bears of Ashenvale or Hillsbrad. &nbsp;Bring me a heap of them and earn yourself a heap of Darkmoon Faire tickets!"},
            [questKeys.objectives] = {nil,nil,{{11407}}},
        },
        [79590] = {
            [questKeys.name] = "Heavy Grinding Stone",
            [questKeys.startedBy] = {{14832}},
            [questKeys.finishedBy] = {{14832,}},
            [questKeys.requiredLevel] = 10,
            [questKeys.questLevel] = 60,
            [questKeys.requiredRaces] = raceIDs.NONE,
            [questKeys.requiredClasses] = classIDs.NONE,
            [questKeys.objectivesText] = {"To help with my workout, I like to fit a staff between heavy grinding stones, then lift the staff over my head. &nbsp;It isn't easy, but being the strongest woman in the world, like I am, can't be earned sitting down!Can you help me? &nbsp;I need more grinding stones - bring me some and I'll trade Darkmoon Faire tickets for them."},
            [questKeys.objectives] = {nil,nil,{{3486}}},
        },
        [79591] = {
            [questKeys.name] = "Whirring Bronze Gizmo",
            [questKeys.startedBy] = {{14841}},
            [questKeys.finishedBy] = {{14841,}},
            [questKeys.requiredLevel] = 10,
            [questKeys.questLevel] = 60,
            [questKeys.requiredRaces] = raceIDs.NONE,
            [questKeys.requiredClasses] = classIDs.NONE,
            [questKeys.objectivesText] = {"My new booth will be a sight to see, yes sir! &nbsp;A sight to see, and... for a lucky few, to touch!I can already hear the whirring bronze gizmos singing their song of mechanical rapture as patrons step to my booth and test their skill!Ah... now I need the gizmos themselves to bring my dream closer to fruition. &nbsp;Please, &lt;name&gt;, bring me whirring bronze gizmos... and Darkmoon Faire tickets will be yours!"},
            [questKeys.objectives] = {nil,nil,{{4375}}},
        },
        [79592] = {
            [questKeys.name] = "Carnival Jerkins",
            [questKeys.startedBy] = {{14833}},
            [questKeys.finishedBy] = {{14833,}},
            [questKeys.requiredLevel] = 10,
            [questKeys.questLevel] = 60,
            [questKeys.requiredRaces] = raceIDs.NONE,
            [questKeys.requiredClasses] = classIDs.NONE,
            [questKeys.objectivesText] = {"Our Faire workers do more than sweep trash and hammer spikes! &nbsp;They also help guard the carnival as it travels, and to that end they are always needing good sturdy armor jerkins.If you make some tough leather armor and bring it to me, then I'll make sure it gets to the right people. &nbsp;I'll also get you some Darkmoon Faire tickets as trade."},
            [questKeys.objectives] = {nil,nil,{{2314}}},
        },
        [79593] = {
            [questKeys.name] = "Coarse Weightstone",
            [questKeys.startedBy] = {{14832}},
            [questKeys.finishedBy] = {{14832,}},
            [questKeys.requiredLevel] = 1,
            [questKeys.questLevel] = 60,
            [questKeys.requiredRaces] = raceIDs.ALL_ALLIANCE,
            [questKeys.requiredClasses] = classIDs.NONE,
            [questKeys.objectivesText] = {"It takes a lot of work to be the strongest woman alive! &nbsp;My weight set is getting too light and if I'm too stay fit then I'll need more weights!Do you think you could bring me some weight stones? &nbsp;If you do, then I'll give you a Darkmoon Faire ticket."},
            [questKeys.objectives] = {nil,nil,{{3240}}},
        },
        [79594] = {
            [questKeys.name] = "Copper Modulator",
            [questKeys.startedBy] = {{14841}},
            [questKeys.finishedBy] = {{14841,}},
            [questKeys.requiredLevel] = 1,
            [questKeys.questLevel] = 60,
            [questKeys.requiredRaces] = raceIDs.NONE,
            [questKeys.requiredClasses] = classIDs.NONE,
            [questKeys.objectivesText] = {"Yebb is developing a new attraction for the Zoo Bizarre, one that will drive people crazy with wonder, and delight! &nbsp;But it will take a lot of work, and a lot of materials...That includes copper modulators. &nbsp;We need lots of modulators for the mechanical parts of the attraction. &nbsp;Bring me copper modulators and I'll trade for them with a Darkmoon Faire ticket."},
            [questKeys.objectives] = {nil,nil,{{4363}}},
        },
        [79595] = {
            [questKeys.name] = "Carnival Boots",
            [questKeys.startedBy] = {{14833}},
            [questKeys.finishedBy] = {{14833,}},
            [questKeys.requiredLevel] = 1,
            [questKeys.questLevel] = 60,
            [questKeys.requiredRaces] = raceIDs.NONE,
            [questKeys.requiredClasses] = classIDs.NONE,
            [questKeys.objectivesText] = {"We at the Darkmoon Faire do much walking. &nbsp;We walk from one faire site to another... in fact, you'll never see us sitting down on the job! &nbsp;So it is no surprise that we wear out quite a lot of boots! &nbsp;We need boots that are both durable and stylish, and embossed leather boots fit that bill rather well.You! &nbsp;You're a leatherworker; make me embossed leather boots and I'll give you a Darkmoon Faire ticket for the work."},
            [questKeys.objectives] = {nil,nil,{{2309}}},
        },
        [79626] = {
            [questKeys.name] = "The Salvagematic 9000!",
            [questKeys.startedBy] = nil,
            [questKeys.finishedBy] = nil,
            [questKeys.requiredLevel] = 40,
            [questKeys.questLevel] = 40,
            [questKeys.requiredRaces] = raceIDs.NONE,
            [questKeys.requiredClasses] = classIDs.NONE,
            [questKeys.objectivesText] = {"Insert a Grime-Encrusted Salvage into the Salvagematic 9000, and be sure to have thirty silver coins to start the machine."},
            [questKeys.objectives] = {nil,nil,{{213427}}},
        },
        [79705] = {
            [questKeys.name] = "Salvaging the Salvagematic",
            [questKeys.startedBy] = {{217689}},
            [questKeys.finishedBy] = nil,
            [questKeys.requiredLevel] = 40,
            [questKeys.questLevel] = 40,
            [questKeys.requiredRaces] = raceIDs.NONE,
            [questKeys.requiredClasses] = classIDs.NONE,
            [questKeys.objectivesText] = {"Bring Ziri \"The Wrench\" 10 Mithril Bars, 5 Greater Mystic Essence, 3 GG12-082 Cartridge Fuses, and a Pristine G-7 C.O.R.E. Processor and she can get the Salvagematic 9000! working for you. Probably. Maybe."},
            [questKeys.objectives] = {nil,nil,{{3860},{216634},{11135},{213735}}},
        },
        [79947] = {
            [questKeys.name] = "Geomancy: The Stone-Cold Truth",
            [questKeys.startedBy] = {{211033}},
            [questKeys.finishedBy] = {{211022,211033,}},
            [questKeys.requiredLevel] = 1,
            [questKeys.questLevel] = 35,
            [questKeys.requiredRaces] = raceIDs.NONE,
            [questKeys.requiredClasses] = classIDs.MAGE,
            [questKeys.objectivesText] = {"Have you brought something to add to our collection?"},
            [questKeys.objectives] = {nil,nil,{{215683}}},
        },
        [79948] = {
            [questKeys.name] = "Defensive Magics 101",
            [questKeys.startedBy] = {{211033}},
            [questKeys.finishedBy] = {{211022,211033,}},
            [questKeys.requiredLevel] = 1,
            [questKeys.questLevel] = 35,
            [questKeys.requiredRaces] = raceIDs.NONE,
            [questKeys.requiredClasses] = classIDs.MAGE,
            [questKeys.objectivesText] = {"Have you brought something to add to our collection?"},
            [questKeys.objectives] = {nil,nil,{{215815}}},
        },
        [79949] = {
            [questKeys.name] = "A Web of Lies: Debunking Myths and Legends",
            [questKeys.startedBy] = {{211033}},
            [questKeys.finishedBy] = {{211022,211033,}},
            [questKeys.requiredLevel] = 1,
            [questKeys.questLevel] = 35,
            [questKeys.requiredRaces] = raceIDs.NONE,
            [questKeys.requiredClasses] = classIDs.MAGE,
            [questKeys.objectivesText] = {"Have you brought something to add to our collection?"},
            [questKeys.objectives] = {nil,nil,{{215816}}},
        },
        [79950] = {
            [questKeys.name] = "Demons and You",
            [questKeys.startedBy] = {{211033}},
            [questKeys.finishedBy] = {{211022,211033,}},
            [questKeys.requiredLevel] = 1,
            [questKeys.questLevel] = 35,
            [questKeys.requiredRaces] = raceIDs.NONE,
            [questKeys.requiredClasses] = classIDs.MAGE,
            [questKeys.objectivesText] = {"Have you brought something to add to our collection?"},
            [questKeys.objectives] = {nil,nil,{{215817}}},
        },
        [79951] = {
            [questKeys.name] = "Mummies: A Guide to the Unsavory Undead",
            [questKeys.startedBy] = {{211033}},
            [questKeys.finishedBy] = {{211022,211033,}},
            [questKeys.requiredLevel] = 1,
            [questKeys.questLevel] = 35,
            [questKeys.requiredRaces] = raceIDs.NONE,
            [questKeys.requiredClasses] = classIDs.MAGE,
            [questKeys.objectivesText] = {"Have you brought something to add to our collection?"},
            [questKeys.objectives] = {nil,nil,{{215820}}},
        },
        [79952] = {
            [questKeys.name] = "RwlRwlRwlRwl!",
            [questKeys.startedBy] = {{211033}},
            [questKeys.finishedBy] = {{211022,211033,}},
            [questKeys.requiredLevel] = 1,
            [questKeys.questLevel] = 35,
            [questKeys.requiredRaces] = raceIDs.NONE,
            [questKeys.requiredClasses] = classIDs.MAGE,
            [questKeys.objectivesText] = {"Have you brought something to add to our collection?"},
            [questKeys.objectives] = {nil,nil,{{215822}}},
        },
        [79953] = {
            [questKeys.name] = "A Ludite's Guide to Caring for Your Demonic Pet",
            [questKeys.startedBy] = {{211033}},
            [questKeys.finishedBy] = {{211022,211033,}},
            [questKeys.requiredLevel] = 1,
            [questKeys.questLevel] = 35,
            [questKeys.requiredRaces] = raceIDs.NONE,
            [questKeys.requiredClasses] = classIDs.MAGE,
            [questKeys.objectivesText] = {"Have you brought something to add to our collection?"},
            [questKeys.objectives] = {nil,nil,{{215824}}},
        },
        [79974] = {
            [questKeys.name] = "Wet Job",
            [questKeys.startedBy] = nil,
            [questKeys.finishedBy] = nil,
            [questKeys.requiredLevel] = 14,
            [questKeys.questLevel] = 40,
            [questKeys.requiredRaces] = raceIDs.NONE,
            [questKeys.requiredClasses] = classIDs.NONE,
            [questKeys.objectivesText] = {"Dusting off a messenger bag emerging from the soil, you find a parchment nestled among the supplies."},
            [questKeys.objectives] = nil,
        },
        [79975] = {
            [questKeys.name] = "Eagle's Fist",
            [questKeys.startedBy] = nil,
            [questKeys.finishedBy] = nil,
            [questKeys.requiredLevel] = 14,
            [questKeys.questLevel] = 40,
            [questKeys.requiredRaces] = raceIDs.NONE,
            [questKeys.requiredClasses] = classIDs.NONE,
            [questKeys.objectivesText] = {"Water spray dampens the air, the view is incredible."},
            [questKeys.objectives] = nil,
        },
        [79976] = {
            [questKeys.name] = "This Must Be The Place",
            [questKeys.startedBy] = nil,
            [questKeys.finishedBy] = nil,
            [questKeys.requiredLevel] = 14,
            [questKeys.questLevel] = 40,
            [questKeys.requiredRaces] = raceIDs.NONE,
            [questKeys.requiredClasses] = classIDs.NONE,
            [questKeys.objectivesText] = {"Whoever was here, you just missed them."},
            [questKeys.objectives] = nil,
        },
        [79980] = {
            [questKeys.name] = "Scramble",
            [questKeys.startedBy] = nil,
            [questKeys.finishedBy] = nil,
            [questKeys.requiredLevel] = 14,
            [questKeys.questLevel] = 40,
            [questKeys.requiredRaces] = raceIDs.NONE,
            [questKeys.requiredClasses] = classIDs.NONE,
            [questKeys.objectivesText] = {"Find what awaits you."},
            [questKeys.objectives] = nil,
        },
        [79981] = {
            [questKeys.name] = "The Corroded Core",
            [questKeys.startedBy] = nil,
            [questKeys.finishedBy] = nil,
            [questKeys.requiredLevel] = 40,
            [questKeys.questLevel] = 40,
            [questKeys.requiredRaces] = raceIDs.NONE,
            [questKeys.requiredClasses] = classIDs.NONE,
            [questKeys.objectivesText] = {"Find someone who can repair the Corroded G-7 C.O.R.E Processor."},
            [questKeys.objectives] = nil,
        },
        [79984] = {
            [questKeys.name] = "Quadrangulation",
            [questKeys.startedBy] = nil,
            [questKeys.finishedBy] = nil,
            [questKeys.requiredLevel] = 40,
            [questKeys.questLevel] = 40,
            [questKeys.requiredRaces] = raceIDs.NONE,
            [questKeys.requiredClasses] = classIDs.NONE,
            [questKeys.objectivesText] = {"Find Wirdal Wondergear's Quadrangulation Beacons and attune with them. There are four of them and they are located somewhere in Kalimdor."},
            [questKeys.objectives] = nil,
        },
        [79986] = {
            [questKeys.name] = "Grime-Encrusted Ring",
            [questKeys.startedBy] = nil,
            [questKeys.finishedBy] = nil,
            [questKeys.requiredLevel] = 40,
            [questKeys.questLevel] = 40,
            [questKeys.requiredRaces] = raceIDs.NONE,
            [questKeys.requiredClasses] = classIDs.NONE,
            [questKeys.objectivesText] = {"Figure out a way to remove the grime from the Grime-Encrusted Ring."},
            [questKeys.objectives] = nil,
        },
        [79987] = {
            [questKeys.name] = "Return of the Ring",
            [questKeys.startedBy] = nil,
            [questKeys.finishedBy] = nil,
            [questKeys.requiredLevel] = 40,
            [questKeys.questLevel] = 40,
            [questKeys.requiredRaces] = raceIDs.ALL_ALLIANCE,
            [questKeys.requiredClasses] = classIDs.NONE,
            [questKeys.objectivesText] = {"You may either keep the ring, or you may find the person responsible for the imprint and engravings on the inside of the band."},
            [questKeys.objectives] = nil,
        },
        [79990] = {
            [questKeys.name] = "Stranglethorn Lumber",
            [questKeys.startedBy] = {{14984}},
            [questKeys.finishedBy] = nil,
            [questKeys.requiredLevel] = 26,
            [questKeys.questLevel] = 40,
            [questKeys.requiredRaces] = raceIDs.ALL_ALLIANCE,
            [questKeys.requiredClasses] = classIDs.NONE,
            [questKeys.objectivesText] = {"Bring Sergeant Maclear a Shipment of Stranglethorn Lumber."},
            [questKeys.objectives] = {nil,nil,{{216491}}},
        },
        [79991] = {
            [questKeys.name] = "Stranglethorn Lumber",
            [questKeys.startedBy] = {{15022}},
            [questKeys.finishedBy] = nil,
            [questKeys.requiredLevel] = 26,
            [questKeys.questLevel] = 40,
            [questKeys.requiredRaces] = raceIDs.ALL_HORDE,
            [questKeys.requiredClasses] = classIDs.NONE,
            [questKeys.objectivesText] = {"Bring Deathstalker Mortis a Shipment of Stranglethorn Lumber."},
            [questKeys.objectives] = {nil,nil,{{216491}}},
        },
        [80001] = {
            [questKeys.name] = "Rekindle",
            [questKeys.startedBy] = nil,
            [questKeys.finishedBy] = nil,
            [questKeys.requiredLevel] = 14,
            [questKeys.questLevel] = 40,
            [questKeys.requiredRaces] = raceIDs.NONE,
            [questKeys.requiredClasses] = classIDs.NONE,
            [questKeys.objectivesText] = {"An extinguished fire pit. The wood is even dry enough to catch a flame."},
            [questKeys.objectives] = {nil,nil,{{4470},{4471}}},
        },
        [80131] = {
            [questKeys.name] = "Gnome Improvement",
            [questKeys.startedBy] = nil,
            [questKeys.finishedBy] = nil,
            [questKeys.requiredLevel] = 40,
            [questKeys.questLevel] = 40,
            [questKeys.requiredRaces] = raceIDs.NONE,
            [questKeys.requiredClasses] = classIDs.NONE,
            [questKeys.objectivesText] = {"Bring the Brilliant Gold Ring, a Silver Bar, a Moss Agate, and 30 silver coins to Talvash del Kissel in Ironforge."},
            [questKeys.objectives] = {nil,nil,{{2842},{1206}}},
        },
        [80132] = {
            [questKeys.name] = "Rig Wars",
            [questKeys.startedBy] = {{3412}},
            [questKeys.finishedBy] = nil,
            [questKeys.requiredLevel] = 40,
            [questKeys.questLevel] = 40,
            [questKeys.requiredRaces] = raceIDs.ALL_HORDE,
            [questKeys.requiredClasses] = classIDs.NONE,
            [questKeys.objectivesText] = {"Retrieve the Rig Blueprints and Thermaplugg's Safe Combination from Gnomeregan and bring them to Nogg in Orgrimmar."},
            [questKeys.objectives] = {nil,nil,{{9153},{9299}}},
        },
        [80133] = {
            [questKeys.name] = "Chief Engineer Scooty",
            [questKeys.startedBy] = nil,
            [questKeys.finishedBy] = {{7853,}},
            [questKeys.requiredLevel] = 40,
            [questKeys.questLevel] = 40,
            [questKeys.requiredRaces] = raceIDs.ALL_HORDE,
            [questKeys.requiredClasses] = classIDs.NONE,
            [questKeys.objectivesText] = {"Speak with Scooty in Booty Bay."},
            [questKeys.objectives] = nil,
        },
        [80134] = {
            [questKeys.name] = "Gnomer-gooooone!",
            [questKeys.startedBy] = {{7853}},
            [questKeys.finishedBy] = {{7853,}},
            [questKeys.requiredLevel] = 40,
            [questKeys.questLevel] = 40,
            [questKeys.requiredRaces] = raceIDs.ALL_HORDE,
            [questKeys.requiredClasses] = classIDs.NONE,
            [questKeys.objectivesText] = {"Wait for Scooty to calibrate the Goblin Transponder."},
            [questKeys.objectives] = nil,
        },
        [80135] = {
            [questKeys.name] = "Klockmort's Essentials",
            [questKeys.startedBy] = nil,
            [questKeys.finishedBy] = nil,
            [questKeys.requiredLevel] = 40,
            [questKeys.questLevel] = 40,
            [questKeys.requiredRaces] = raceIDs.NONE,
            [questKeys.requiredClasses] = classIDs.NONE,
            [questKeys.objectivesText] = {"Speak with Klockmort Spannerspan in Ironforge."},
            [questKeys.objectives] = nil,
        },
        [80136] = {
            [questKeys.name] = "Essential Artificials",
            [questKeys.startedBy] = {{6169}},
            [questKeys.finishedBy] = nil,
            [questKeys.requiredLevel] = 40,
            [questKeys.questLevel] = 40,
            [questKeys.requiredRaces] = raceIDs.ALL_ALLIANCE,
            [questKeys.requiredClasses] = classIDs.NONE,
            [questKeys.objectivesText] = {"Bring 12 Essential Artificials to Klockmort Spannerspan in Ironforge."},
            [questKeys.objectives] = {nil,nil,{{9278}}},
        },
        [80137] = {
            [questKeys.name] = "Save Techbot's Brain!",
            [questKeys.startedBy] = {{7944}},
            [questKeys.finishedBy] = {{7944,}},
            [questKeys.requiredLevel] = 40,
            [questKeys.questLevel] = 40,
            [questKeys.requiredRaces] = raceIDs.ALL_ALLIANCE,
            [questKeys.requiredClasses] = classIDs.NONE,
            [questKeys.objectivesText] = {"Bring Techbot's Memory Core to Tinkmaster Overspark in Ironforge."},
            [questKeys.objectives] = {nil,nil,{{9277}}},
        },
        [80138] = {
            [questKeys.name] = "Tinkmaster Overspark",
            [questKeys.startedBy] = {{7917}},
            [questKeys.finishedBy] = {{7944,}},
            [questKeys.requiredLevel] = 40,
            [questKeys.questLevel] = 40,
            [questKeys.requiredRaces] = raceIDs.ALL_ALLIANCE,
            [questKeys.requiredClasses] = classIDs.NONE,
            [questKeys.objectivesText] = {"Speak with Tinkmaster Overspark in Ironforge."},
            [questKeys.objectives] = nil,
        },
        [80139] = {
            [questKeys.name] = "Gnogaine",
            [questKeys.startedBy] = nil,
            [questKeys.finishedBy] = nil,
            [questKeys.requiredLevel] = 40,
            [questKeys.questLevel] = 40,
            [questKeys.requiredRaces] = raceIDs.NONE,
            [questKeys.requiredClasses] = classIDs.NONE,
            [questKeys.objectivesText] = {"Use the Empty Leaden Collection Phial on Irradiated Invaders or Irradiated Pillagers to collect radioactive fallout. Once it is full, take it back to Ozzie Togglevolt in Kharanos."},
            [questKeys.objectives] = {nil,nil,{{9284},{9283}}},
        },
        [80140] = {
            [questKeys.name] = "Return of the Ring",
            [questKeys.startedBy] = nil,
            [questKeys.finishedBy] = nil,
            [questKeys.requiredLevel] = 40,
            [questKeys.questLevel] = 40,
            [questKeys.requiredRaces] = raceIDs.NONE,
            [questKeys.requiredClasses] = classIDs.NONE,
            [questKeys.objectivesText] = {"You may either keep the ring, or you may find the person responsible for the imprint and engravings on the inside of the band."},
            [questKeys.objectives] = nil,
        },
        [80141] = {
            [questKeys.name] = "Nogg's Ring Redo",
            [questKeys.startedBy] = nil,
            [questKeys.finishedBy] = nil,
            [questKeys.requiredLevel] = 40,
            [questKeys.questLevel] = 40,
            [questKeys.requiredRaces] = raceIDs.NONE,
            [questKeys.requiredClasses] = classIDs.NONE,
            [questKeys.objectivesText] = {"Bring the Brilliant Gold Ring, a Silver Bar, a Moss Agate, and 30 silver coins to Nogg in Orgrimmar."},
            [questKeys.objectives] = {nil,nil,{{2842},{1206}}},
        },
        [80143] = {
            [questKeys.name] = "Data Rescue",
            [questKeys.startedBy] = {{7950}},
            [questKeys.finishedBy] = {{7950,}},
            [questKeys.requiredLevel] = 40,
            [questKeys.questLevel] = 40,
            [questKeys.requiredRaces] = raceIDs.ALL_ALLIANCE,
            [questKeys.requiredClasses] = classIDs.NONE,
            [questKeys.objectivesText] = {"Bring a Prismatic Punch Card to Master Mechanic Castpipe in Ironforge."},
            [questKeys.objectives] = {nil,nil,{{9316}}},
        },
        [80153] = {
            [questKeys.name] = "The Sparklematic 5200!",
            [questKeys.startedBy] = nil,
            [questKeys.finishedBy] = nil,
            [questKeys.requiredLevel] = 40,
            [questKeys.questLevel] = 40,
            [questKeys.requiredRaces] = raceIDs.NONE,
            [questKeys.requiredClasses] = classIDs.NONE,
            [questKeys.objectivesText] = {"Insert a Grime-Encrusted Item into the Sparklematic 5200, and be sure to have three silver coins to start the machine."},
            [questKeys.objectives] = {nil,nil,{{9308}}},
        },
        [80155] = {
            [questKeys.name] = "More Sparklematic Action",
            [questKeys.startedBy] = nil,
            [questKeys.finishedBy] = nil,
            [questKeys.requiredLevel] = 40,
            [questKeys.questLevel] = 40,
            [questKeys.requiredRaces] = raceIDs.NONE,
            [questKeys.requiredClasses] = classIDs.NONE,
            [questKeys.objectivesText] = {"The Sparklematic 5200 is empty, awaiting a grime-encrusted object to clean and three silver coins to start!"},
            [questKeys.objectives] = {nil,nil,{{9308}}},
        },
        [80157] = {
            [questKeys.name] = "The Sparklematic 5200!",
            [questKeys.startedBy] = nil,
            [questKeys.finishedBy] = nil,
            [questKeys.requiredLevel] = 40,
            [questKeys.questLevel] = 40,
            [questKeys.requiredRaces] = raceIDs.NONE,
            [questKeys.requiredClasses] = classIDs.NONE,
            [questKeys.objectivesText] = {"As quickly as it started, the Sparklematic 5200 comes to an abrupt halt. &nbsp;A simple \"ding\" is heard from the machine, and the mouth of the machine spirals upward. &nbsp;Inside the Sparklematic 5200 is a small box wrapped in a little bow. &nbsp;The machine would appear to wrap an object up after eliminating its grime-encrusted status. &nbsp;Even if the machine didn't work, at least the item is now wrapped in a pretty box.Well, there is one way to find out if it cleaned the item or not..."},
            [questKeys.objectives] = nil,
        },
        [80158] = {
            [questKeys.name] = "The Sparklematic 5200!",
            [questKeys.startedBy] = nil,
            [questKeys.finishedBy] = nil,
            [questKeys.requiredLevel] = 40,
            [questKeys.questLevel] = 40,
            [questKeys.requiredRaces] = raceIDs.NONE,
            [questKeys.requiredClasses] = classIDs.NONE,
            [questKeys.objectivesText] = {"Insert a Grime-Encrusted Item into the Sparklematic 5200, and be sure to have three silver coins to start the machine."},
            [questKeys.objectives] = {nil,nil,{{9308}}},
        },
        [80160] = {
            [questKeys.name] = "More Sparklematic Action",
            [questKeys.startedBy] = nil,
            [questKeys.finishedBy] = nil,
            [questKeys.requiredLevel] = 40,
            [questKeys.questLevel] = 40,
            [questKeys.requiredRaces] = raceIDs.NONE,
            [questKeys.requiredClasses] = classIDs.NONE,
            [questKeys.objectivesText] = {"The Sparklematic 5200 is empty, awaiting a grime-encrusted object to clean and three silver coins to start!"},
            [questKeys.objectives] = {nil,nil,{{9308}}},
        },
        [80161] = {
            [questKeys.name] = "The Sparklematic 5200!",
            [questKeys.startedBy] = nil,
            [questKeys.finishedBy] = nil,
            [questKeys.requiredLevel] = 40,
            [questKeys.questLevel] = 40,
            [questKeys.requiredRaces] = raceIDs.NONE,
            [questKeys.requiredClasses] = classIDs.NONE,
            [questKeys.objectivesText] = {"As quickly as it started, the Sparklematic 5200 comes to an abrupt halt. &nbsp;A simple \"ding\" is heard from the machine, and the mouth of the machine spirals upward. &nbsp;Inside the Sparklematic 5200 is a small box wrapped in a little bow. &nbsp;The machine would appear to wrap an object up after eliminating its grime-encrusted status. &nbsp;Even if the machine didn't work, at least the item is now wrapped in a pretty box.Well, there is one way to find out if it cleaned the item or not..."},
            [questKeys.objectives] = nil,
        },
        [80180] = {
            [questKeys.name] = "The Grand Betrayal",
            [questKeys.startedBy] = {{7937}},
            [questKeys.finishedBy] = nil,
            [questKeys.requiredLevel] = 40,
            [questKeys.questLevel] = 40,
            [questKeys.requiredRaces] = raceIDs.ALL_ALLIANCE,
            [questKeys.requiredClasses] = classIDs.NONE,
            [questKeys.objectivesText] = {"Venture to Gnomeregan and kill Mekgineer Thermaplugg. Return to High Tinker Mekkatorque when the task is complete."},
            [questKeys.objectives] = nil,
        },
        [80181] = {
            [questKeys.name] = "Gyrodrillmatic Excavationators",
            [questKeys.startedBy] = {{6579}},
            [questKeys.finishedBy] = nil,
            [questKeys.requiredLevel] = 40,
            [questKeys.questLevel] = 40,
            [questKeys.requiredRaces] = raceIDs.ALL_ALLIANCE,
            [questKeys.requiredClasses] = classIDs.NONE,
            [questKeys.objectivesText] = {"Bring twenty-four Robo-mechanical Guts to Shoni in Stormwind."},
            [questKeys.objectives] = {nil,nil,{{9309}}},
        },
        [80182] = {
            [questKeys.name] = "The Only Cure is More Green Glow",
            [questKeys.startedBy] = nil,
            [questKeys.finishedBy] = nil,
            [questKeys.requiredLevel] = 40,
            [questKeys.questLevel] = 40,
            [questKeys.requiredRaces] = raceIDs.NONE,
            [questKeys.requiredClasses] = classIDs.NONE,
            [questKeys.objectivesText] = {"Travel to Gnomeregan and bring back High Potency Radioactive Fallout. Be warned, the fallout is unstable and will collapse rather quickly.Ozzie will also require your Heavy Leaden Collection Phial when the task is complete."},
            [questKeys.objectives] = {nil,nil,{{9365}}},
        },
        [80307] = {
            [questKeys.name] = "A Full Shipment",
            [questKeys.startedBy] = {{214099}},
            [questKeys.finishedBy] = {{213077,214070,214096,214099,}},
            [questKeys.requiredLevel] = 1,
            [questKeys.questLevel] = 28,
            [questKeys.requiredRaces] = raceIDs.NONE,
            [questKeys.requiredClasses] = classIDs.NONE,
            [questKeys.objectivesText] = {"Do you have something for me?"},
            [questKeys.objectives] = {nil,nil,{{217337}}},
        },
        [80308] = {
            [questKeys.name] = "A Full Shipment",
            [questKeys.startedBy] = {{214099}},
            [questKeys.finishedBy] = {{213077,214096,214099,}},
            [questKeys.requiredLevel] = 1,
            [questKeys.questLevel] = 35,
            [questKeys.requiredRaces] = raceIDs.NONE,
            [questKeys.requiredClasses] = classIDs.NONE,
            [questKeys.objectivesText] = {"Do you have something for me?"},
            [questKeys.objectives] = {nil,nil,{{217338}}},
        },
        [80309] = {
            [questKeys.name] = "A Full Shipment",
            [questKeys.startedBy] = nil,
            [questKeys.finishedBy] = nil,
            [questKeys.requiredLevel] = 1,
            [questKeys.questLevel] = 40,
            [questKeys.requiredRaces] = raceIDs.NONE,
            [questKeys.requiredClasses] = classIDs.NONE,
            [questKeys.objectivesText] = nil,
            [questKeys.objectives] = {nil,nil,{{217339}}},
        },
        [80324] = {
            [questKeys.name] = "The Mad King",
            [questKeys.startedBy] = nil,
            [questKeys.finishedBy] = nil,
            [questKeys.requiredLevel] = 40,
            [questKeys.questLevel] = 40,
            [questKeys.requiredRaces] = raceIDs.NONE,
            [questKeys.requiredClasses] = classIDs.NONE,
            [questKeys.objectivesText] = {"Bring Thermaplugg's Engineering Notes to High Tinker Mekkatorque at Tinker Town in Ironforge."},
            [questKeys.objectives] = nil,
        },
        [80325] = {
            [questKeys.name] = "The Mad King",
            [questKeys.startedBy] = nil,
            [questKeys.finishedBy] = nil,
            [questKeys.requiredLevel] = 40,
            [questKeys.questLevel] = 40,
            [questKeys.requiredRaces] = raceIDs.NONE,
            [questKeys.requiredClasses] = classIDs.NONE,
            [questKeys.objectivesText] = {"Bring Thermaplugg's Engineering Notes to Nogg at the Valley of Honor in Orgrimmar."},
            [questKeys.objectives] = nil,
        },
    }
end
